# herdsdk
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.178.0-SNAPSHOT
- Package version: 0.178.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import herdsdk 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import herdsdk
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import herdsdk
from herdsdk.rest import ApiException
from pprint import pprint

# Configure HTTP basic authorization: basicAuth
configuration = herdsdk.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'
# Configure OAuth2 access token for authorization: oauthAuth
configuration = herdsdk.Configuration()
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# create an instance of the API class
api_instance = herdsdk.AllowedAttributeValueApi(herdsdk.ApiClient(configuration))
allowed_attribute_values_create_request = herdsdk.AllowedAttributeValuesCreateRequest() # AllowedAttributeValuesCreateRequest | the information needed to create the allowed attribute values

try:
    # createAllowedAttributeValues
    api_response = api_instance.allowed_attribute_value_create_allowed_attribute_values(allowed_attribute_values_create_request)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AllowedAttributeValueApi->allowed_attribute_value_create_allowed_attribute_values: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost/herd-app/rest*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AllowedAttributeValueApi* | [**allowed_attribute_value_create_allowed_attribute_values**](docs/AllowedAttributeValueApi.md#allowed_attribute_value_create_allowed_attribute_values) | **POST** /allowedAttributeValues | createAllowedAttributeValues
*AllowedAttributeValueApi* | [**allowed_attribute_value_delete_allowed_attribute_values**](docs/AllowedAttributeValueApi.md#allowed_attribute_value_delete_allowed_attribute_values) | **DELETE** /allowedAttributeValues | deleteAllowedAttributeValues
*AllowedAttributeValueApi* | [**allowed_attribute_value_get_allowed_attribute_values**](docs/AllowedAttributeValueApi.md#allowed_attribute_value_get_allowed_attribute_values) | **GET** /allowedAttributeValues/namespaces/{namespace}/attributeValueListNames/{attributeValueListName} | getAllowedAttributeValues
*ApplicationApi* | [**application_get_build_info**](docs/ApplicationApi.md#application_get_build_info) | **GET** /buildInfo | Gets the build information
*AttributeValueListApi* | [**attribute_value_list_create_attribute_value_list**](docs/AttributeValueListApi.md#attribute_value_list_create_attribute_value_list) | **POST** /attributeValueLists | createAttributeValueList
*AttributeValueListApi* | [**attribute_value_list_delete_attribute_value_list**](docs/AttributeValueListApi.md#attribute_value_list_delete_attribute_value_list) | **DELETE** /attributeValueLists/namespaces/{namespace}/attributeValueListNames/{attributeValueListName} | deleteAttributeValueList
*AttributeValueListApi* | [**attribute_value_list_get_attribute_value_list**](docs/AttributeValueListApi.md#attribute_value_list_get_attribute_value_list) | **GET** /attributeValueLists/namespaces/{namespace}/attributeValueListNames/{attributeValueListName} | getAttributeValueList
*AttributeValueListApi* | [**attribute_value_list_get_attribute_value_lists**](docs/AttributeValueListApi.md#attribute_value_list_get_attribute_value_lists) | **GET** /attributeValueLists | getAttributeValueLists
*BusinessObjectDataApi* | [**business_object_data_check_business_object_data_availability**](docs/BusinessObjectDataApi.md#business_object_data_check_business_object_data_availability) | **POST** /businessObjectData/availability | checkBusinessObjectDataAvailability
*BusinessObjectDataApi* | [**business_object_data_check_business_object_data_availability_collection**](docs/BusinessObjectDataApi.md#business_object_data_check_business_object_data_availability_collection) | **POST** /businessObjectData/availabilityCollection | checkBusinessObjectDataAvailabilityCollection
*BusinessObjectDataApi* | [**business_object_data_create_business_object_data**](docs/BusinessObjectDataApi.md#business_object_data_create_business_object_data) | **POST** /businessObjectData | createBusinessObjectData
*BusinessObjectDataApi* | [**business_object_data_delete_business_object_data**](docs/BusinessObjectDataApi.md#business_object_data_delete_business_object_data) | **DELETE** /businessObjectData/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/businessObjectDataVersions/{businessObjectDataVersion} | deleteBusinessObjectData
*BusinessObjectDataApi* | [**business_object_data_delete_business_object_data1**](docs/BusinessObjectDataApi.md#business_object_data_delete_business_object_data1) | **DELETE** /businessObjectData/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/businessObjectDataVersions/{businessObjectDataVersion} | deleteBusinessObjectData
*BusinessObjectDataApi* | [**business_object_data_delete_business_object_data2**](docs/BusinessObjectDataApi.md#business_object_data_delete_business_object_data2) | **DELETE** /businessObjectData/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/subPartition2Values/{subPartition2Value}/businessObjectDataVersions/{businessObjectDataVersion} | deleteBusinessObjectData
*BusinessObjectDataApi* | [**business_object_data_delete_business_object_data3**](docs/BusinessObjectDataApi.md#business_object_data_delete_business_object_data3) | **DELETE** /businessObjectData/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/subPartition2Values/{subPartition2Value}/subPartition3Values/{subPartition3Value}/businessObjectDataVersions/{businessObjectDataVersion} | deleteBusinessObjectData
*BusinessObjectDataApi* | [**business_object_data_delete_business_object_data4**](docs/BusinessObjectDataApi.md#business_object_data_delete_business_object_data4) | **DELETE** /businessObjectData/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/subPartition2Values/{subPartition2Value}/subPartition3Values/{subPartition3Value}/subPartition4Values/{subPartition4Value}/businessObjectDataVersions/{businessObjectDataVersion} | deleteBusinessObjectData
*BusinessObjectDataApi* | [**business_object_data_destroy_business_object_data**](docs/BusinessObjectDataApi.md#business_object_data_destroy_business_object_data) | **POST** /businessObjectData/destroy/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/businessObjectDataVersions/{businessObjectDataVersion} | destroyBusinessObjectData
*BusinessObjectDataApi* | [**business_object_data_generate_business_object_data_ddl**](docs/BusinessObjectDataApi.md#business_object_data_generate_business_object_data_ddl) | **POST** /businessObjectData/generateDdl | generateBusinessObjectDataDdl
*BusinessObjectDataApi* | [**business_object_data_generate_business_object_data_ddl_collection**](docs/BusinessObjectDataApi.md#business_object_data_generate_business_object_data_ddl_collection) | **POST** /businessObjectData/generateDdlCollection | generateBusinessObjectDataDdlCollection
*BusinessObjectDataApi* | [**business_object_data_generate_business_object_data_partitions**](docs/BusinessObjectDataApi.md#business_object_data_generate_business_object_data_partitions) | **POST** /businessObjectData/generatePartitions | generateBusinessObjectDataPartitions
*BusinessObjectDataApi* | [**business_object_data_get_all_business_object_data_by_business_object_definition**](docs/BusinessObjectDataApi.md#business_object_data_get_all_business_object_data_by_business_object_definition) | **GET** /businessObjectData/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName} | getAllBusinessObjectDataByBusinessObjectDefinition
*BusinessObjectDataApi* | [**business_object_data_get_all_business_object_data_by_business_object_format**](docs/BusinessObjectDataApi.md#business_object_data_get_all_business_object_data_by_business_object_format) | **GET** /businessObjectData/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion} | getAllBusinessObjectDataByBusinessObjectFormat
*BusinessObjectDataApi* | [**business_object_data_get_business_object_data**](docs/BusinessObjectDataApi.md#business_object_data_get_business_object_data) | **GET** /businessObjectData/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType} | getBusinessObjectData
*BusinessObjectDataApi* | [**business_object_data_get_business_object_data_versions**](docs/BusinessObjectDataApi.md#business_object_data_get_business_object_data_versions) | **GET** /businessObjectData/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/versions | getBusinessObjectDataVersions
*BusinessObjectDataApi* | [**business_object_data_get_s3_key_prefix**](docs/BusinessObjectDataApi.md#business_object_data_get_s3_key_prefix) | **GET** /businessObjectData/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/s3KeyPrefix | Gets the S3 key prefix information for a specified namespace
*BusinessObjectDataApi* | [**business_object_data_invalidate_unregistered_business_object_data**](docs/BusinessObjectDataApi.md#business_object_data_invalidate_unregistered_business_object_data) | **POST** /businessObjectData/unregistered/invalidation | invalidateUnregisteredBusinessObjectData
*BusinessObjectDataApi* | [**business_object_data_restore_business_object_data**](docs/BusinessObjectDataApi.md#business_object_data_restore_business_object_data) | **POST** /businessObjectData/restore/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/businessObjectDataVersions/{businessObjectDataVersion} | restoreBusinessObjectData
*BusinessObjectDataApi* | [**business_object_data_retry_storage_policy_transition**](docs/BusinessObjectDataApi.md#business_object_data_retry_storage_policy_transition) | **POST** /businessObjectData/retryStoragePolicyTransition/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/businessObjectDataVersions/{businessObjectDataVersion} | retryStoragePolicyTransition
*BusinessObjectDataApi* | [**business_object_data_search_business_object_data**](docs/BusinessObjectDataApi.md#business_object_data_search_business_object_data) | **POST** /businessObjectData/search | searchBusinessObjectData
*BusinessObjectDataApi* | [**business_object_data_update_business_object_data_attributes**](docs/BusinessObjectDataApi.md#business_object_data_update_business_object_data_attributes) | **PUT** /businessObjectDataAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/businessObjectDataVersions/{businessObjectDataVersion} | updateBusinessObjectDataAttributes
*BusinessObjectDataApi* | [**business_object_data_update_business_object_data_attributes1**](docs/BusinessObjectDataApi.md#business_object_data_update_business_object_data_attributes1) | **PUT** /businessObjectDataAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/businessObjectDataVersions/{businessObjectDataVersion} | updateBusinessObjectDataAttributes
*BusinessObjectDataApi* | [**business_object_data_update_business_object_data_attributes2**](docs/BusinessObjectDataApi.md#business_object_data_update_business_object_data_attributes2) | **PUT** /businessObjectDataAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/subPartition2Values/{subPartition2Value}/businessObjectDataVersions/{businessObjectDataVersion} | updateBusinessObjectDataAttributes
*BusinessObjectDataApi* | [**business_object_data_update_business_object_data_attributes3**](docs/BusinessObjectDataApi.md#business_object_data_update_business_object_data_attributes3) | **PUT** /businessObjectDataAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/subPartition2Values/{subPartition2Value}/subPartition3Values/{subPartition3Value}/businessObjectDataVersions/{businessObjectDataVersion} | updateBusinessObjectDataAttributes
*BusinessObjectDataApi* | [**business_object_data_update_business_object_data_attributes4**](docs/BusinessObjectDataApi.md#business_object_data_update_business_object_data_attributes4) | **PUT** /businessObjectDataAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/subPartition2Values/{subPartition2Value}/subPartition3Values/{subPartition3Value}/subPartition4Values/{subPartition4Value}/businessObjectDataVersions/{businessObjectDataVersion} | updateBusinessObjectDataAttributes
*BusinessObjectDataApi* | [**business_object_data_update_business_object_data_legal_hold**](docs/BusinessObjectDataApi.md#business_object_data_update_business_object_data_legal_hold) | **PUT** /businessObjectDataLegalHold/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/businessObjectDataVersions/{businessObjectDataVersion} | updateBusinessObjectDataLegalHold
*BusinessObjectDataApi* | [**business_object_data_update_business_object_data_parents**](docs/BusinessObjectDataApi.md#business_object_data_update_business_object_data_parents) | **PUT** /businessObjectDataParents/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/businessObjectDataVersions/{businessObjectDataVersion} | updateBusinessObjectDataParents
*BusinessObjectDataApi* | [**business_object_data_update_business_object_data_retention_information**](docs/BusinessObjectDataApi.md#business_object_data_update_business_object_data_retention_information) | **PUT** /businessObjectDataRetentionInformation/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/businessObjectDataVersions/{businessObjectDataVersion} | updateBusinessObjectDataRetentionInformation
*BusinessObjectDataAttributeApi* | [**business_object_data_attribute_create_business_object_data_attribute**](docs/BusinessObjectDataAttributeApi.md#business_object_data_attribute_create_business_object_data_attribute) | **POST** /businessObjectDataAttributes | createBusinessObjectDataAttribute
*BusinessObjectDataAttributeApi* | [**business_object_data_attribute_delete_business_object_data_attribute**](docs/BusinessObjectDataAttributeApi.md#business_object_data_attribute_delete_business_object_data_attribute) | **DELETE** /businessObjectDataAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/businessObjectDataVersions/{businessObjectDataVersion}/businessObjectDataAttributeNames/{businessObjectDataAttributeName} | deleteBusinessObjectDataAttribute
*BusinessObjectDataAttributeApi* | [**business_object_data_attribute_delete_business_object_data_attribute1**](docs/BusinessObjectDataAttributeApi.md#business_object_data_attribute_delete_business_object_data_attribute1) | **DELETE** /businessObjectDataAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/businessObjectDataVersions/{businessObjectDataVersion}/businessObjectDataAttributeNames/{businessObjectDataAttributeName} | deleteBusinessObjectDataAttribute
*BusinessObjectDataAttributeApi* | [**business_object_data_attribute_delete_business_object_data_attribute2**](docs/BusinessObjectDataAttributeApi.md#business_object_data_attribute_delete_business_object_data_attribute2) | **DELETE** /businessObjectDataAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/subPartition2Values/{subPartition2Value}/businessObjectDataVersions/{businessObjectDataVersion}/businessObjectDataAttributeNames/{businessObjectDataAttributeName} | deleteBusinessObjectDataAttribute
*BusinessObjectDataAttributeApi* | [**business_object_data_attribute_delete_business_object_data_attribute3**](docs/BusinessObjectDataAttributeApi.md#business_object_data_attribute_delete_business_object_data_attribute3) | **DELETE** /businessObjectDataAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/subPartition2Values/{subPartition2Value}/subPartition3Values/{subPartition3Value}/businessObjectDataVersions/{businessObjectDataVersion}/businessObjectDataAttributeNames/{businessObjectDataAttributeName} | deleteBusinessObjectDataAttribute
*BusinessObjectDataAttributeApi* | [**business_object_data_attribute_delete_business_object_data_attribute4**](docs/BusinessObjectDataAttributeApi.md#business_object_data_attribute_delete_business_object_data_attribute4) | **DELETE** /businessObjectDataAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/subPartition2Values/{subPartition2Value}/subPartition3Values/{subPartition3Value}/subPartition4Values/{subPartition4Value}/businessObjectDataVersions/{businessObjectDataVersion}/businessObjectDataAttributeNames/{businessObjectDataAttributeName} | deleteBusinessObjectDataAttribute
*BusinessObjectDataAttributeApi* | [**business_object_data_attribute_get_business_object_data_attribute**](docs/BusinessObjectDataAttributeApi.md#business_object_data_attribute_get_business_object_data_attribute) | **GET** /businessObjectDataAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/businessObjectDataVersions/{businessObjectDataVersion}/businessObjectDataAttributeNames/{businessObjectDataAttributeName} | getBusinessObjectDataAttribute
*BusinessObjectDataAttributeApi* | [**business_object_data_attribute_get_business_object_data_attribute1**](docs/BusinessObjectDataAttributeApi.md#business_object_data_attribute_get_business_object_data_attribute1) | **GET** /businessObjectDataAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/businessObjectDataVersions/{businessObjectDataVersion}/businessObjectDataAttributeNames/{businessObjectDataAttributeName} | getBusinessObjectDataAttribute
*BusinessObjectDataAttributeApi* | [**business_object_data_attribute_get_business_object_data_attribute2**](docs/BusinessObjectDataAttributeApi.md#business_object_data_attribute_get_business_object_data_attribute2) | **GET** /businessObjectDataAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/subPartition2Values/{subPartition2Value}/businessObjectDataVersions/{businessObjectDataVersion}/businessObjectDataAttributeNames/{businessObjectDataAttributeName} | getBusinessObjectDataAttribute
*BusinessObjectDataAttributeApi* | [**business_object_data_attribute_get_business_object_data_attribute3**](docs/BusinessObjectDataAttributeApi.md#business_object_data_attribute_get_business_object_data_attribute3) | **GET** /businessObjectDataAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/subPartition2Values/{subPartition2Value}/subPartition3Values/{subPartition3Value}/businessObjectDataVersions/{businessObjectDataVersion}/businessObjectDataAttributeNames/{businessObjectDataAttributeName} | getBusinessObjectDataAttribute
*BusinessObjectDataAttributeApi* | [**business_object_data_attribute_get_business_object_data_attribute4**](docs/BusinessObjectDataAttributeApi.md#business_object_data_attribute_get_business_object_data_attribute4) | **GET** /businessObjectDataAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/subPartition2Values/{subPartition2Value}/subPartition3Values/{subPartition3Value}/subPartition4Values/{subPartition4Value}/businessObjectDataVersions/{businessObjectDataVersion}/businessObjectDataAttributeNames/{businessObjectDataAttributeName} | getBusinessObjectDataAttribute
*BusinessObjectDataAttributeApi* | [**business_object_data_attribute_get_business_object_data_attributes**](docs/BusinessObjectDataAttributeApi.md#business_object_data_attribute_get_business_object_data_attributes) | **GET** /businessObjectDataAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/businessObjectDataVersions/{businessObjectDataVersion} | getBusinessObjectDataAttributes
*BusinessObjectDataAttributeApi* | [**business_object_data_attribute_get_business_object_data_attributes1**](docs/BusinessObjectDataAttributeApi.md#business_object_data_attribute_get_business_object_data_attributes1) | **GET** /businessObjectDataAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/businessObjectDataVersions/{businessObjectDataVersion} | getBusinessObjectDataAttributes
*BusinessObjectDataAttributeApi* | [**business_object_data_attribute_get_business_object_data_attributes2**](docs/BusinessObjectDataAttributeApi.md#business_object_data_attribute_get_business_object_data_attributes2) | **GET** /businessObjectDataAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/subPartition2Values/{subPartition2Value}/businessObjectDataVersions/{businessObjectDataVersion} | getBusinessObjectDataAttributes
*BusinessObjectDataAttributeApi* | [**business_object_data_attribute_get_business_object_data_attributes3**](docs/BusinessObjectDataAttributeApi.md#business_object_data_attribute_get_business_object_data_attributes3) | **GET** /businessObjectDataAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/subPartition2Values/{subPartition2Value}/subPartition3Values/{subPartition3Value}/businessObjectDataVersions/{businessObjectDataVersion} | getBusinessObjectDataAttributes
*BusinessObjectDataAttributeApi* | [**business_object_data_attribute_get_business_object_data_attributes4**](docs/BusinessObjectDataAttributeApi.md#business_object_data_attribute_get_business_object_data_attributes4) | **GET** /businessObjectDataAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/subPartition2Values/{subPartition2Value}/subPartition3Values/{subPartition3Value}/subPartition4Values/{subPartition4Value}/businessObjectDataVersions/{businessObjectDataVersion} | getBusinessObjectDataAttributes
*BusinessObjectDataAttributeApi* | [**business_object_data_attribute_update_business_object_data_attribute**](docs/BusinessObjectDataAttributeApi.md#business_object_data_attribute_update_business_object_data_attribute) | **PUT** /businessObjectDataAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/businessObjectDataVersions/{businessObjectDataVersion}/businessObjectDataAttributeNames/{businessObjectDataAttributeName} | updateBusinessObjectDataAttribute
*BusinessObjectDataAttributeApi* | [**business_object_data_attribute_update_business_object_data_attribute1**](docs/BusinessObjectDataAttributeApi.md#business_object_data_attribute_update_business_object_data_attribute1) | **PUT** /businessObjectDataAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/businessObjectDataVersions/{businessObjectDataVersion}/businessObjectDataAttributeNames/{businessObjectDataAttributeName} | updateBusinessObjectDataAttribute
*BusinessObjectDataAttributeApi* | [**business_object_data_attribute_update_business_object_data_attribute2**](docs/BusinessObjectDataAttributeApi.md#business_object_data_attribute_update_business_object_data_attribute2) | **PUT** /businessObjectDataAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/subPartition2Values/{subPartition2Value}/businessObjectDataVersions/{businessObjectDataVersion}/businessObjectDataAttributeNames/{businessObjectDataAttributeName} | updateBusinessObjectDataAttribute
*BusinessObjectDataAttributeApi* | [**business_object_data_attribute_update_business_object_data_attribute3**](docs/BusinessObjectDataAttributeApi.md#business_object_data_attribute_update_business_object_data_attribute3) | **PUT** /businessObjectDataAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/subPartition2Values/{subPartition2Value}/subPartition3Values/{subPartition3Value}/businessObjectDataVersions/{businessObjectDataVersion}/businessObjectDataAttributeNames/{businessObjectDataAttributeName} | updateBusinessObjectDataAttribute
*BusinessObjectDataAttributeApi* | [**business_object_data_attribute_update_business_object_data_attribute4**](docs/BusinessObjectDataAttributeApi.md#business_object_data_attribute_update_business_object_data_attribute4) | **PUT** /businessObjectDataAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/subPartition2Values/{subPartition2Value}/subPartition3Values/{subPartition3Value}/subPartition4Values/{subPartition4Value}/businessObjectDataVersions/{businessObjectDataVersion}/businessObjectDataAttributeNames/{businessObjectDataAttributeName} | updateBusinessObjectDataAttribute
*BusinessObjectDataNotificationRegistrationApi* | [**business_object_data_notification_registration_create_business_object_data_notification_registration**](docs/BusinessObjectDataNotificationRegistrationApi.md#business_object_data_notification_registration_create_business_object_data_notification_registration) | **POST** /notificationRegistrations/businessObjectDataNotificationRegistrations | createBusinessObjectDataNotificationRegistration
*BusinessObjectDataNotificationRegistrationApi* | [**business_object_data_notification_registration_delete_business_object_data_notification**](docs/BusinessObjectDataNotificationRegistrationApi.md#business_object_data_notification_registration_delete_business_object_data_notification) | **DELETE** /notificationRegistrations/businessObjectDataNotificationRegistrations/namespaces/{namespace}/notificationNames/{notificationName} | deleteBusinessObjectDataNotification
*BusinessObjectDataNotificationRegistrationApi* | [**business_object_data_notification_registration_get_business_object_data_notification_registration**](docs/BusinessObjectDataNotificationRegistrationApi.md#business_object_data_notification_registration_get_business_object_data_notification_registration) | **GET** /notificationRegistrations/businessObjectDataNotificationRegistrations/namespaces/{namespace}/notificationNames/{notificationName} | getBusinessObjectDataNotificationRegistration
*BusinessObjectDataNotificationRegistrationApi* | [**business_object_data_notification_registration_get_business_object_data_notification_registrations_by_namespace**](docs/BusinessObjectDataNotificationRegistrationApi.md#business_object_data_notification_registration_get_business_object_data_notification_registrations_by_namespace) | **GET** /notificationRegistrations/businessObjectDataNotificationRegistrations/namespaces/{namespace} | getBusinessObjectDataNotificationRegistrationsByNamespace
*BusinessObjectDataNotificationRegistrationApi* | [**business_object_data_notification_registration_get_business_object_data_notification_registrations_by_notification_filter**](docs/BusinessObjectDataNotificationRegistrationApi.md#business_object_data_notification_registration_get_business_object_data_notification_registrations_by_notification_filter) | **GET** /notificationRegistrations/businessObjectDataNotificationRegistrations | getBusinessObjectDataNotificationRegistrationsByNotificationFilter
*BusinessObjectDataNotificationRegistrationApi* | [**business_object_data_notification_registration_update_business_object_data_notification_registration**](docs/BusinessObjectDataNotificationRegistrationApi.md#business_object_data_notification_registration_update_business_object_data_notification_registration) | **PUT** /notificationRegistrations/businessObjectDataNotificationRegistrations/namespaces/{namespace}/notificationNames/{notificationName} | updateBusinessObjectDataNotificationRegistration
*BusinessObjectDataStatusApi* | [**business_object_data_status_get_business_object_data_status**](docs/BusinessObjectDataStatusApi.md#business_object_data_status_get_business_object_data_status) | **GET** /businessObjectDataStatus/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType} | getBusinessObjectDataStatus
*BusinessObjectDataStatusApi* | [**business_object_data_status_update_business_object_data_status**](docs/BusinessObjectDataStatusApi.md#business_object_data_status_update_business_object_data_status) | **PUT** /businessObjectDataStatus/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/businessObjectDataVersions/{businessObjectDataVersion} | updateBusinessObjectDataStatus
*BusinessObjectDataStatusApi* | [**business_object_data_status_update_business_object_data_status1**](docs/BusinessObjectDataStatusApi.md#business_object_data_status_update_business_object_data_status1) | **PUT** /businessObjectDataStatus/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/businessObjectDataVersions/{businessObjectDataVersion} | updateBusinessObjectDataStatus
*BusinessObjectDataStatusApi* | [**business_object_data_status_update_business_object_data_status2**](docs/BusinessObjectDataStatusApi.md#business_object_data_status_update_business_object_data_status2) | **PUT** /businessObjectDataStatus/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/subPartition2Values/{subPartition2Value}/businessObjectDataVersions/{businessObjectDataVersion} | updateBusinessObjectDataStatus
*BusinessObjectDataStatusApi* | [**business_object_data_status_update_business_object_data_status3**](docs/BusinessObjectDataStatusApi.md#business_object_data_status_update_business_object_data_status3) | **PUT** /businessObjectDataStatus/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/subPartition2Values/{subPartition2Value}/subPartition3Values/{subPartition3Value}/businessObjectDataVersions/{businessObjectDataVersion} | updateBusinessObjectDataStatus
*BusinessObjectDataStatusApi* | [**business_object_data_status_update_business_object_data_status4**](docs/BusinessObjectDataStatusApi.md#business_object_data_status_update_business_object_data_status4) | **PUT** /businessObjectDataStatus/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/subPartition2Values/{subPartition2Value}/subPartition3Values/{subPartition3Value}/subPartition4Values/{subPartition4Value}/businessObjectDataVersions/{businessObjectDataVersion} | updateBusinessObjectDataStatus
*BusinessObjectDataStorageFileApi* | [**business_object_data_storage_file_create_business_object_data_storage_files**](docs/BusinessObjectDataStorageFileApi.md#business_object_data_storage_file_create_business_object_data_storage_files) | **POST** /businessObjectDataStorageFiles | createBusinessObjectDataStorageFiles
*BusinessObjectDataStorageUnitApi* | [**business_object_data_storage_unit_create_business_object_data_storage_unit**](docs/BusinessObjectDataStorageUnitApi.md#business_object_data_storage_unit_create_business_object_data_storage_unit) | **POST** /businessObjectDataStorageUnits | createBusinessObjectDataStorageUnit
*BusinessObjectDataStorageUnitStatusApi* | [**business_object_data_storage_unit_status_update_business_object_data_storage_unit_status**](docs/BusinessObjectDataStorageUnitStatusApi.md#business_object_data_storage_unit_status_update_business_object_data_storage_unit_status) | **PUT** /businessObjectDataStorageUnitStatus/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/businessObjectDataVersions/{businessObjectDataVersion}/storageNames/{storageName} | updateBusinessObjectDataStorageUnitStatus
*BusinessObjectDataStorageUnitStatusApi* | [**business_object_data_storage_unit_status_update_business_object_data_storage_unit_status1**](docs/BusinessObjectDataStorageUnitStatusApi.md#business_object_data_storage_unit_status_update_business_object_data_storage_unit_status1) | **PUT** /businessObjectDataStorageUnitStatus/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/businessObjectDataVersions/{businessObjectDataVersion}/storageNames/{storageName} | updateBusinessObjectDataStorageUnitStatus
*BusinessObjectDataStorageUnitStatusApi* | [**business_object_data_storage_unit_status_update_business_object_data_storage_unit_status2**](docs/BusinessObjectDataStorageUnitStatusApi.md#business_object_data_storage_unit_status_update_business_object_data_storage_unit_status2) | **PUT** /businessObjectDataStorageUnitStatus/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/subPartition2Values/{subPartition2Value}/businessObjectDataVersions/{businessObjectDataVersion}/storageNames/{storageName} | updateBusinessObjectDataStorageUnitStatus
*BusinessObjectDataStorageUnitStatusApi* | [**business_object_data_storage_unit_status_update_business_object_data_storage_unit_status3**](docs/BusinessObjectDataStorageUnitStatusApi.md#business_object_data_storage_unit_status_update_business_object_data_storage_unit_status3) | **PUT** /businessObjectDataStorageUnitStatus/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/subPartition2Values/{subPartition2Value}/subPartition3Values/{subPartition3Value}/businessObjectDataVersions/{businessObjectDataVersion}/storageNames/{storageName} | updateBusinessObjectDataStorageUnitStatus
*BusinessObjectDataStorageUnitStatusApi* | [**business_object_data_storage_unit_status_update_business_object_data_storage_unit_status4**](docs/BusinessObjectDataStorageUnitStatusApi.md#business_object_data_storage_unit_status_update_business_object_data_storage_unit_status4) | **PUT** /businessObjectDataStorageUnitStatus/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/subPartition1Values/{subPartition1Value}/subPartition2Values/{subPartition2Value}/subPartition3Values/{subPartition3Value}/subPartition4Values/{subPartition4Value}/businessObjectDataVersions/{businessObjectDataVersion}/storageNames/{storageName} | updateBusinessObjectDataStorageUnitStatus
*BusinessObjectDefinitionApi* | [**business_object_definition_create_business_object_definition**](docs/BusinessObjectDefinitionApi.md#business_object_definition_create_business_object_definition) | **POST** /businessObjectDefinitions | createBusinessObjectDefinition
*BusinessObjectDefinitionApi* | [**business_object_definition_delete_business_object_definition**](docs/BusinessObjectDefinitionApi.md#business_object_definition_delete_business_object_definition) | **DELETE** /businessObjectDefinitions/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName} | deleteBusinessObjectDefinition
*BusinessObjectDefinitionApi* | [**business_object_definition_get_business_object_definition**](docs/BusinessObjectDefinitionApi.md#business_object_definition_get_business_object_definition) | **GET** /businessObjectDefinitions/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName} | getBusinessObjectDefinition
*BusinessObjectDefinitionApi* | [**business_object_definition_get_business_object_definitions**](docs/BusinessObjectDefinitionApi.md#business_object_definition_get_business_object_definitions) | **GET** /businessObjectDefinitions | getBusinessObjectDefinitions
*BusinessObjectDefinitionApi* | [**business_object_definition_get_business_object_definitions1**](docs/BusinessObjectDefinitionApi.md#business_object_definition_get_business_object_definitions1) | **GET** /businessObjectDefinitions/namespaces/{namespace} | getBusinessObjectDefinitions
*BusinessObjectDefinitionApi* | [**business_object_definition_search_business_object_definitions**](docs/BusinessObjectDefinitionApi.md#business_object_definition_search_business_object_definitions) | **POST** /businessObjectDefinitions/search | searchBusinessObjectDefinitions
*BusinessObjectDefinitionApi* | [**business_object_definition_update_business_object_definition**](docs/BusinessObjectDefinitionApi.md#business_object_definition_update_business_object_definition) | **PUT** /businessObjectDefinitions/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName} | updateBusinessObjectDefinition
*BusinessObjectDefinitionApi* | [**business_object_definition_update_business_object_definition_descriptive_information**](docs/BusinessObjectDefinitionApi.md#business_object_definition_update_business_object_definition_descriptive_information) | **PUT** /businessObjectDefinitionDescriptiveInformation/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName} | updateBusinessObjectDefinitionDescriptiveInformation
*BusinessObjectDefinitionColumnApi* | [**business_object_definition_column_create_business_object_definition_column**](docs/BusinessObjectDefinitionColumnApi.md#business_object_definition_column_create_business_object_definition_column) | **POST** /businessObjectDefinitionColumns | createBusinessObjectDefinitionColumn
*BusinessObjectDefinitionColumnApi* | [**business_object_definition_column_delete_business_object_definition_column**](docs/BusinessObjectDefinitionColumnApi.md#business_object_definition_column_delete_business_object_definition_column) | **DELETE** /businessObjectDefinitionColumns/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectDefinitionColumnNames/{businessObjectDefinitionColumnName} | deleteBusinessObjectDefinitionColumn
*BusinessObjectDefinitionColumnApi* | [**business_object_definition_column_get_business_object_definition_column**](docs/BusinessObjectDefinitionColumnApi.md#business_object_definition_column_get_business_object_definition_column) | **GET** /businessObjectDefinitionColumns/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectDefinitionColumnNames/{businessObjectDefinitionColumnName} | getBusinessObjectDefinitionColumn
*BusinessObjectDefinitionColumnApi* | [**business_object_definition_column_get_business_object_definition_columns**](docs/BusinessObjectDefinitionColumnApi.md#business_object_definition_column_get_business_object_definition_columns) | **GET** /businessObjectDefinitionColumns/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName} | getBusinessObjectDefinitionColumns
*BusinessObjectDefinitionColumnApi* | [**business_object_definition_column_search_business_object_definition_columns**](docs/BusinessObjectDefinitionColumnApi.md#business_object_definition_column_search_business_object_definition_columns) | **POST** /businessObjectDefinitionColumns/search | searchBusinessObjectDefinitionColumns
*BusinessObjectDefinitionColumnApi* | [**business_object_definition_column_update_business_object_definition_column**](docs/BusinessObjectDefinitionColumnApi.md#business_object_definition_column_update_business_object_definition_column) | **PUT** /businessObjectDefinitionColumns/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectDefinitionColumnNames/{businessObjectDefinitionColumnName} | updateBusinessObjectDefinitionColumn
*BusinessObjectDefinitionDescriptionSuggestionApi* | [**business_object_definition_description_suggestion_accept_business_object_definition_description_suggestion**](docs/BusinessObjectDefinitionDescriptionSuggestionApi.md#business_object_definition_description_suggestion_accept_business_object_definition_description_suggestion) | **POST** /businessObjectDefinitionDescriptionSuggestions/acceptance | acceptBusinessObjectDefinitionDescriptionSuggestion
*BusinessObjectDefinitionDescriptionSuggestionApi* | [**business_object_definition_description_suggestion_create_business_object_definition_description_suggestion**](docs/BusinessObjectDefinitionDescriptionSuggestionApi.md#business_object_definition_description_suggestion_create_business_object_definition_description_suggestion) | **POST** /businessObjectDefinitionDescriptionSuggestions | createBusinessObjectDefinitionDescriptionSuggestion
*BusinessObjectDefinitionDescriptionSuggestionApi* | [**business_object_definition_description_suggestion_delete_business_object_definition_description_suggestion**](docs/BusinessObjectDefinitionDescriptionSuggestionApi.md#business_object_definition_description_suggestion_delete_business_object_definition_description_suggestion) | **DELETE** /businessObjectDefinitionDescriptionSuggestions/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/userIds/{userId} | deleteBusinessObjectDefinitionDescriptionSuggestion
*BusinessObjectDefinitionDescriptionSuggestionApi* | [**business_object_definition_description_suggestion_get_business_object_definition_description_suggestion_by_key**](docs/BusinessObjectDefinitionDescriptionSuggestionApi.md#business_object_definition_description_suggestion_get_business_object_definition_description_suggestion_by_key) | **GET** /businessObjectDefinitionDescriptionSuggestions/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/userIds/{userId} | getBusinessObjectDefinitionDescriptionSuggestionByKey
*BusinessObjectDefinitionDescriptionSuggestionApi* | [**business_object_definition_description_suggestion_get_business_object_definition_description_suggestions**](docs/BusinessObjectDefinitionDescriptionSuggestionApi.md#business_object_definition_description_suggestion_get_business_object_definition_description_suggestions) | **GET** /businessObjectDefinitionDescriptionSuggestions/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName} | getBusinessObjectDefinitionDescriptionSuggestions
*BusinessObjectDefinitionDescriptionSuggestionApi* | [**business_object_definition_description_suggestion_search_business_object_definition_description_suggestions**](docs/BusinessObjectDefinitionDescriptionSuggestionApi.md#business_object_definition_description_suggestion_search_business_object_definition_description_suggestions) | **POST** /businessObjectDefinitionDescriptionSuggestions/search | searchBusinessObjectDefinitionDescriptionSuggestions
*BusinessObjectDefinitionDescriptionSuggestionApi* | [**business_object_definition_description_suggestion_update_business_object_definition_description_suggestion**](docs/BusinessObjectDefinitionDescriptionSuggestionApi.md#business_object_definition_description_suggestion_update_business_object_definition_description_suggestion) | **PUT** /businessObjectDefinitionDescriptionSuggestions/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/userIds/{userId} | updateBusinessObjectDefinitionDescriptionSuggestion
*BusinessObjectDefinitionSubjectMatterExpertApi* | [**business_object_definition_subject_matter_expert_create_business_object_definition_subject_matter_expert**](docs/BusinessObjectDefinitionSubjectMatterExpertApi.md#business_object_definition_subject_matter_expert_create_business_object_definition_subject_matter_expert) | **POST** /businessObjectDefinitionSubjectMatterExperts | createBusinessObjectDefinitionSubjectMatterExpert
*BusinessObjectDefinitionSubjectMatterExpertApi* | [**business_object_definition_subject_matter_expert_delete_business_object_definition_subject_matter_expert**](docs/BusinessObjectDefinitionSubjectMatterExpertApi.md#business_object_definition_subject_matter_expert_delete_business_object_definition_subject_matter_expert) | **DELETE** /businessObjectDefinitionSubjectMatterExperts/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/userIds/{userId} | deleteBusinessObjectDefinitionSubjectMatterExpert
*BusinessObjectDefinitionSubjectMatterExpertApi* | [**business_object_definition_subject_matter_expert_get_business_object_definition_subject_matter_experts_by_business_object_definition**](docs/BusinessObjectDefinitionSubjectMatterExpertApi.md#business_object_definition_subject_matter_expert_get_business_object_definition_subject_matter_experts_by_business_object_definition) | **GET** /businessObjectDefinitionSubjectMatterExperts/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName} | getBusinessObjectDefinitionSubjectMatterExpertsByBusinessObjectDefinition
*BusinessObjectDefinitionTagApi* | [**business_object_definition_tag_create_business_object_definition_tag**](docs/BusinessObjectDefinitionTagApi.md#business_object_definition_tag_create_business_object_definition_tag) | **POST** /businessObjectDefinitionTags | createBusinessObjectDefinitionTag
*BusinessObjectDefinitionTagApi* | [**business_object_definition_tag_delete_business_object_definition_tag**](docs/BusinessObjectDefinitionTagApi.md#business_object_definition_tag_delete_business_object_definition_tag) | **DELETE** /businessObjectDefinitionTags/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/tagTypes/{tagTypeCode}/tagCodes/{tagCode} | deleteBusinessObjectDefinitionTag
*BusinessObjectDefinitionTagApi* | [**business_object_definition_tag_get_business_object_definition_tags_by_business_object_definition**](docs/BusinessObjectDefinitionTagApi.md#business_object_definition_tag_get_business_object_definition_tags_by_business_object_definition) | **GET** /businessObjectDefinitionTags/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName} | getBusinessObjectDefinitionTagsByBusinessObjectDefinition
*BusinessObjectDefinitionTagApi* | [**business_object_definition_tag_get_business_object_definition_tags_by_tag**](docs/BusinessObjectDefinitionTagApi.md#business_object_definition_tag_get_business_object_definition_tags_by_tag) | **GET** /businessObjectDefinitionTags/tagTypes/{tagTypeCode}/tagCodes/{tagCode} | getBusinessObjectDefinitionTagsByTag
*BusinessObjectFormatApi* | [**business_object_format_create_business_object_format**](docs/BusinessObjectFormatApi.md#business_object_format_create_business_object_format) | **POST** /businessObjectFormats | createBusinessObjectFormat
*BusinessObjectFormatApi* | [**business_object_format_delete_business_object_format**](docs/BusinessObjectFormatApi.md#business_object_format_delete_business_object_format) | **DELETE** /businessObjectFormats/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion} | deleteBusinessObjectFormat
*BusinessObjectFormatApi* | [**business_object_format_generate_business_object_format_ddl**](docs/BusinessObjectFormatApi.md#business_object_format_generate_business_object_format_ddl) | **POST** /businessObjectFormats/generateDdl | generateBusinessObjectFormatDdl
*BusinessObjectFormatApi* | [**business_object_format_generate_business_object_format_ddl_collection**](docs/BusinessObjectFormatApi.md#business_object_format_generate_business_object_format_ddl_collection) | **POST** /businessObjectFormats/generateDdlCollection | generateBusinessObjectFormatDdlCollection
*BusinessObjectFormatApi* | [**business_object_format_get_business_object_format**](docs/BusinessObjectFormatApi.md#business_object_format_get_business_object_format) | **GET** /businessObjectFormats/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType} | getBusinessObjectFormat
*BusinessObjectFormatApi* | [**business_object_format_get_business_object_formats**](docs/BusinessObjectFormatApi.md#business_object_format_get_business_object_formats) | **GET** /businessObjectFormats/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName} | getBusinessObjectFormats
*BusinessObjectFormatApi* | [**business_object_format_get_business_object_formats_with_filters**](docs/BusinessObjectFormatApi.md#business_object_format_get_business_object_formats_with_filters) | **GET** /businessObjectFormats/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage} | getBusinessObjectFormatsWithFilters
*BusinessObjectFormatApi* | [**business_object_format_update_business_object_format**](docs/BusinessObjectFormatApi.md#business_object_format_update_business_object_format) | **PUT** /businessObjectFormats/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion} | updateBusinessObjectFormat
*BusinessObjectFormatApi* | [**business_object_format_update_business_object_format_attribute_definitions**](docs/BusinessObjectFormatApi.md#business_object_format_update_business_object_format_attribute_definitions) | **PUT** /businessObjectFormatAttributeDefinitions/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion} | updateBusinessObjectFormatAttributeDefinitions
*BusinessObjectFormatApi* | [**business_object_format_update_business_object_format_attributes**](docs/BusinessObjectFormatApi.md#business_object_format_update_business_object_format_attributes) | **PUT** /businessObjectFormatAttributes/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion} | updateBusinessObjectFormatAttributes
*BusinessObjectFormatApi* | [**business_object_format_update_business_object_format_legal_hold**](docs/BusinessObjectFormatApi.md#business_object_format_update_business_object_format_legal_hold) | **PUT** /businessObjectFormatLegalHold/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType} | updateBusinessObjectFormatLegalHold
*BusinessObjectFormatApi* | [**business_object_format_update_business_object_format_parents**](docs/BusinessObjectFormatApi.md#business_object_format_update_business_object_format_parents) | **PUT** /businessObjectFormatParents/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType} | updateBusinessObjectFormatParents
*BusinessObjectFormatApi* | [**business_object_format_update_business_object_format_record_flag**](docs/BusinessObjectFormatApi.md#business_object_format_update_business_object_format_record_flag) | **PUT** /businessObjectFormatRecordFlag/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType} | updateBusinessObjectFormatRecordFlag
*BusinessObjectFormatApi* | [**business_object_format_update_business_object_format_retention_information**](docs/BusinessObjectFormatApi.md#business_object_format_update_business_object_format_retention_information) | **PUT** /businessObjectFormatRetentionInformation/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType} | updateBusinessObjectFormatRetentionInformation
*BusinessObjectFormatApi* | [**business_object_format_update_business_object_format_schema_backwards_compatible_changes**](docs/BusinessObjectFormatApi.md#business_object_format_update_business_object_format_schema_backwards_compatible_changes) | **PUT** /businessObjectFormatSchemaBackwardsCompatibility/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType} | updateBusinessObjectFormatSchemaBackwardsCompatibleChanges
*BusinessObjectFormatExternalInterfaceDescriptiveInformationApi* | [**business_object_format_external_interface_descriptive_information_get_business_object_format_external_interface**](docs/BusinessObjectFormatExternalInterfaceDescriptiveInformationApi.md#business_object_format_external_interface_descriptive_information_get_business_object_format_external_interface) | **GET** /businessObjectFormatExternalInterfaceDescriptiveInformation/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/externalInterfaceNames/{externalInterfaceName} | getBusinessObjectFormatExternalInterface
*BusinessObjectFormatToExternalInterfaceMappingApi* | [**business_object_formatto_external_interface_mapping_create_business_object_format_external_interface**](docs/BusinessObjectFormatToExternalInterfaceMappingApi.md#business_object_formatto_external_interface_mapping_create_business_object_format_external_interface) | **POST** /businessObjectFormatExternalInterfaces | createBusinessObjectFormatExternalInterface
*BusinessObjectFormatToExternalInterfaceMappingApi* | [**business_object_formatto_external_interface_mapping_delete_business_object_format_external_interface**](docs/BusinessObjectFormatToExternalInterfaceMappingApi.md#business_object_formatto_external_interface_mapping_delete_business_object_format_external_interface) | **DELETE** /businessObjectFormatExternalInterfaces/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/externalInterfaceNames/{externalInterfaceName} | deleteBusinessObjectFormatExternalInterface
*BusinessObjectFormatToExternalInterfaceMappingApi* | [**business_object_formatto_external_interface_mapping_get_business_object_format_external_interface**](docs/BusinessObjectFormatToExternalInterfaceMappingApi.md#business_object_formatto_external_interface_mapping_get_business_object_format_external_interface) | **GET** /businessObjectFormatExternalInterfaces/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/externalInterfaceNames/{externalInterfaceName} | getBusinessObjectFormatExternalInterface
*ConfigurationEntryApi* | [**configuration_entry_get_configuration_entries**](docs/ConfigurationEntryApi.md#configuration_entry_get_configuration_entries) | **GET** /configurationEntries | getConfigurationEntries
*ConfigurationEntryApi* | [**configuration_entry_get_configuration_entry**](docs/ConfigurationEntryApi.md#configuration_entry_get_configuration_entry) | **GET** /configurationEntries/{configurationEntryKey} | getConfigurationEntry
*CurrentUserApi* | [**current_user_get_current_user**](docs/CurrentUserApi.md#current_user_get_current_user) | **GET** /currentUser | getCurrentUser
*CustomDDLApi* | [**custom_ddl_create_custom_ddl**](docs/CustomDDLApi.md#custom_ddl_create_custom_ddl) | **POST** /customDdls | createCustomDdl
*CustomDDLApi* | [**custom_ddl_delete_custom_ddl**](docs/CustomDDLApi.md#custom_ddl_delete_custom_ddl) | **DELETE** /customDdls/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/customDdlNames/{customDdlName} | deleteCustomDdl
*CustomDDLApi* | [**custom_ddl_get_custom_ddl**](docs/CustomDDLApi.md#custom_ddl_get_custom_ddl) | **GET** /customDdls/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/customDdlNames/{customDdlName} | getCustomDdl
*CustomDDLApi* | [**custom_ddl_get_custom_ddls**](docs/CustomDDLApi.md#custom_ddl_get_custom_ddls) | **GET** /customDdls/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion} | getCustomDdls
*CustomDDLApi* | [**custom_ddl_update_custom_ddl**](docs/CustomDDLApi.md#custom_ddl_update_custom_ddl) | **PUT** /customDdls/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/customDdlNames/{customDdlName} | updateCustomDdl
*DataProviderApi* | [**data_provider_create_data_provider**](docs/DataProviderApi.md#data_provider_create_data_provider) | **POST** /dataProviders | createDataProvider
*DataProviderApi* | [**data_provider_delete_data_provider**](docs/DataProviderApi.md#data_provider_delete_data_provider) | **DELETE** /dataProviders/{dataProviderName} | deleteDataProvider
*DataProviderApi* | [**data_provider_get_data_provider**](docs/DataProviderApi.md#data_provider_get_data_provider) | **GET** /dataProviders/{dataProviderName} | getDataProvider
*DataProviderApi* | [**data_provider_get_data_providers**](docs/DataProviderApi.md#data_provider_get_data_providers) | **GET** /dataProviders | getDataProviders
*EMRApi* | [**e_mr_add_hadoop_jar_step_to_emr_cluster**](docs/EMRApi.md#e_mr_add_hadoop_jar_step_to_emr_cluster) | **POST** /emrHadoopJarSteps | addHadoopJarStepToEmrCluster
*EMRApi* | [**e_mr_add_hive_step_to_emr_cluster**](docs/EMRApi.md#e_mr_add_hive_step_to_emr_cluster) | **POST** /emrHiveSteps | addHiveStepToEmrCluster
*EMRApi* | [**e_mr_add_pig_step_to_emr_cluster**](docs/EMRApi.md#e_mr_add_pig_step_to_emr_cluster) | **POST** /emrPigSteps | addPigStepToEmrCluster
*EMRApi* | [**e_mr_add_shell_step_to_emr_cluster**](docs/EMRApi.md#e_mr_add_shell_step_to_emr_cluster) | **POST** /emrShellSteps | addShellStepToEmrCluster
*EMRApi* | [**e_mr_create_emr_cluster**](docs/EMRApi.md#e_mr_create_emr_cluster) | **POST** /emrClusters | createEmrCluster
*EMRApi* | [**e_mr_get_emr_cluster**](docs/EMRApi.md#e_mr_get_emr_cluster) | **GET** /emrClusters/namespaces/{namespace}/emrClusterDefinitionNames/{emrClusterDefinitionName}/emrClusterNames/{emrClusterName} | getEmrCluster
*EMRApi* | [**e_mr_terminate_emr_cluster**](docs/EMRApi.md#e_mr_terminate_emr_cluster) | **DELETE** /emrClusters/namespaces/{namespace}/emrClusterDefinitionNames/{emrClusterDefinitionName}/emrClusterNames/{emrClusterName} | terminateEmrCluster
*EMRClusterDefinitionApi* | [**e_mr_cluster_definition_create_emr_cluster_definition**](docs/EMRClusterDefinitionApi.md#e_mr_cluster_definition_create_emr_cluster_definition) | **POST** /emrClusterDefinitions | createEmrClusterDefinition
*EMRClusterDefinitionApi* | [**e_mr_cluster_definition_delete_emr_cluster_definition**](docs/EMRClusterDefinitionApi.md#e_mr_cluster_definition_delete_emr_cluster_definition) | **DELETE** /emrClusterDefinitions/namespaces/{namespace}/emrClusterDefinitionNames/{emrClusterDefinitionName} | deleteEmrClusterDefinition
*EMRClusterDefinitionApi* | [**e_mr_cluster_definition_get_emr_cluster_definition**](docs/EMRClusterDefinitionApi.md#e_mr_cluster_definition_get_emr_cluster_definition) | **GET** /emrClusterDefinitions/namespaces/{namespace}/emrClusterDefinitionNames/{emrClusterDefinitionName} | getEmrClusterDefinition
*EMRClusterDefinitionApi* | [**e_mr_cluster_definition_get_emr_cluster_definitions**](docs/EMRClusterDefinitionApi.md#e_mr_cluster_definition_get_emr_cluster_definitions) | **GET** /emrClusterDefinitions/namespaces/{namespace} | getEmrClusterDefinitions
*EMRClusterDefinitionApi* | [**e_mr_cluster_definition_update_emr_cluster_definition**](docs/EMRClusterDefinitionApi.md#e_mr_cluster_definition_update_emr_cluster_definition) | **PUT** /emrClusterDefinitions/namespaces/{namespace}/emrClusterDefinitionNames/{emrClusterDefinitionName} | updateEmrClusterDefinition
*ExpectedPartitionValueApi* | [**expected_partition_value_create_expected_partition_values**](docs/ExpectedPartitionValueApi.md#expected_partition_value_create_expected_partition_values) | **POST** /expectedPartitionValues | createExpectedPartitionValues
*ExpectedPartitionValueApi* | [**expected_partition_value_delete_expected_partition_values**](docs/ExpectedPartitionValueApi.md#expected_partition_value_delete_expected_partition_values) | **DELETE** /expectedPartitionValues | deleteExpectedPartitionValues
*ExpectedPartitionValueApi* | [**expected_partition_value_get_expected_partition_value**](docs/ExpectedPartitionValueApi.md#expected_partition_value_get_expected_partition_value) | **GET** /expectedPartitionValues/partitionKeyGroups/{partitionKeyGroupName}/expectedPartitionValues/{expectedPartitionValue} | getExpectedPartitionValue
*ExpectedPartitionValueApi* | [**expected_partition_value_get_expected_partition_values**](docs/ExpectedPartitionValueApi.md#expected_partition_value_get_expected_partition_values) | **GET** /expectedPartitionValues/partitionKeyGroups/{partitionKeyGroupName} | getExpectedPartitionValues
*ExternalInterfaceApi* | [**external_interface_create_external_interface**](docs/ExternalInterfaceApi.md#external_interface_create_external_interface) | **POST** /externalInterfaces | createExternalInterface
*ExternalInterfaceApi* | [**external_interface_delete_external_interface**](docs/ExternalInterfaceApi.md#external_interface_delete_external_interface) | **DELETE** /externalInterfaces/{externalInterfaceName} | deleteExternalInterface
*ExternalInterfaceApi* | [**external_interface_get_external_interface**](docs/ExternalInterfaceApi.md#external_interface_get_external_interface) | **GET** /externalInterfaces/{externalInterfaceName} | getExternalInterface
*ExternalInterfaceApi* | [**external_interface_get_external_interfaces**](docs/ExternalInterfaceApi.md#external_interface_get_external_interfaces) | **GET** /externalInterfaces | getExternalInterfaces
*ExternalInterfaceApi* | [**external_interface_update_external_interface**](docs/ExternalInterfaceApi.md#external_interface_update_external_interface) | **PUT** /externalInterfaces/{externalInterfaceName} | updateExternalInterface
*FileTypeApi* | [**file_type_create_file_type**](docs/FileTypeApi.md#file_type_create_file_type) | **POST** /fileTypes | createFileType
*FileTypeApi* | [**file_type_delete_file_type**](docs/FileTypeApi.md#file_type_delete_file_type) | **DELETE** /fileTypes/{fileTypeCode} | deleteFileType
*FileTypeApi* | [**file_type_get_file_type**](docs/FileTypeApi.md#file_type_get_file_type) | **GET** /fileTypes/{fileTypeCode} | getFileType
*FileTypeApi* | [**file_type_get_file_types**](docs/FileTypeApi.md#file_type_get_file_types) | **GET** /fileTypes | getFileTypes
*GlobalAttributeDefinitionApi* | [**global_attribute_definition_create_global_attribute_definition**](docs/GlobalAttributeDefinitionApi.md#global_attribute_definition_create_global_attribute_definition) | **POST** /globalAttributeDefinitions | createGlobalAttributeDefinition
*GlobalAttributeDefinitionApi* | [**global_attribute_definition_delete_global_attribute_definition**](docs/GlobalAttributeDefinitionApi.md#global_attribute_definition_delete_global_attribute_definition) | **DELETE** /globalAttributeDefinitions/globalAttributeDefinitionLevels/{globalAttributeDefinitionLevel}/globalAttributeDefinitionNames/{globalAttributeDefinitionName} | deleteGlobalAttributeDefinition
*GlobalAttributeDefinitionApi* | [**global_attribute_definition_get_global_attribute_definition**](docs/GlobalAttributeDefinitionApi.md#global_attribute_definition_get_global_attribute_definition) | **GET** /globalAttributeDefinitions/globalAttributeDefinitionLevels/{globalAttributeDefinitionLevel}/globalAttributeDefinitionNames/{globalAttributeDefinitionName} | getGlobalAttributeDefinition
*GlobalAttributeDefinitionApi* | [**global_attribute_definition_get_global_attribute_definitions**](docs/GlobalAttributeDefinitionApi.md#global_attribute_definition_get_global_attribute_definitions) | **GET** /globalAttributeDefinitions | getGlobalAttributeDefinitions
*IndexSearchApi* | [**index_search_index_search**](docs/IndexSearchApi.md#index_search_index_search) | **POST** /indexSearch | indexSearch
*JobApi* | [**job_create_job**](docs/JobApi.md#job_create_job) | **POST** /jobs | createJob
*JobApi* | [**job_delete_job**](docs/JobApi.md#job_delete_job) | **DELETE** /jobs/ids/{id} | deleteJob
*JobApi* | [**job_get_job**](docs/JobApi.md#job_get_job) | **GET** /jobs/ids/{id} | getJob
*JobApi* | [**job_get_jobs**](docs/JobApi.md#job_get_jobs) | **GET** /jobs | getJobs
*JobApi* | [**job_signal_job**](docs/JobApi.md#job_signal_job) | **POST** /jobs/signal | signalJob
*JobApi* | [**job_update_job**](docs/JobApi.md#job_update_job) | **PUT** /jobs/ids/{id} | updateJob
*JobDefinitionApi* | [**job_definition_create_job_definition**](docs/JobDefinitionApi.md#job_definition_create_job_definition) | **POST** /jobDefinitions | createJobDefinition
*JobDefinitionApi* | [**job_definition_get_job_definition**](docs/JobDefinitionApi.md#job_definition_get_job_definition) | **GET** /jobDefinitions/namespaces/{namespace}/jobNames/{jobName} | getJobDefinition
*JobDefinitionApi* | [**job_definition_get_job_definition_keys**](docs/JobDefinitionApi.md#job_definition_get_job_definition_keys) | **GET** /jobDefinitions/namespaces/{namespace} | getJobDefinitionKeys
*JobDefinitionApi* | [**job_definition_update_job_definition**](docs/JobDefinitionApi.md#job_definition_update_job_definition) | **PUT** /jobDefinitions/namespaces/{namespace}/jobNames/{jobName} | updateJobDefinition
*NamespaceApi* | [**namespace_create_namespace**](docs/NamespaceApi.md#namespace_create_namespace) | **POST** /namespaces | createNamespace
*NamespaceApi* | [**namespace_delete_namespace**](docs/NamespaceApi.md#namespace_delete_namespace) | **DELETE** /namespaces/{namespaceCode} | deleteNamespace
*NamespaceApi* | [**namespace_get_namespace**](docs/NamespaceApi.md#namespace_get_namespace) | **GET** /namespaces/{namespaceCode} | getNamespace
*NamespaceApi* | [**namespace_get_namespaces**](docs/NamespaceApi.md#namespace_get_namespaces) | **GET** /namespaces | getNamespaces
*NamespaceApi* | [**namespace_search_namespaces**](docs/NamespaceApi.md#namespace_search_namespaces) | **POST** /namespaces/search | searchNamespaces
*NamespaceApi* | [**namespace_update_namespaces**](docs/NamespaceApi.md#namespace_update_namespaces) | **PUT** /namespaces/{namespaceCode} | updateNamespaces
*NamespaceIAMRoleAuthorizationApi* | [**namespace_iam_role_authorization_create_namespace_iam_role_authorization**](docs/NamespaceIAMRoleAuthorizationApi.md#namespace_iam_role_authorization_create_namespace_iam_role_authorization) | **POST** /namespaceIamRoleAuthorizations | createNamespaceIamRoleAuthorization
*NamespaceIAMRoleAuthorizationApi* | [**namespace_iam_role_authorization_delete_namespace_iam_role_authorization**](docs/NamespaceIAMRoleAuthorizationApi.md#namespace_iam_role_authorization_delete_namespace_iam_role_authorization) | **DELETE** /namespaceIamRoleAuthorizations/namespaces/{namespace}/iamRoleNames/{iamRoleName} | deleteNamespaceIamRoleAuthorization
*NamespaceIAMRoleAuthorizationApi* | [**namespace_iam_role_authorization_get_namespace_iam_role_authorization**](docs/NamespaceIAMRoleAuthorizationApi.md#namespace_iam_role_authorization_get_namespace_iam_role_authorization) | **GET** /namespaceIamRoleAuthorizations/namespaces/{namespace}/iamRoleNames/{iamRoleName} | getNamespaceIamRoleAuthorization
*NamespaceIAMRoleAuthorizationApi* | [**namespace_iam_role_authorization_get_namespace_iam_role_authorizations**](docs/NamespaceIAMRoleAuthorizationApi.md#namespace_iam_role_authorization_get_namespace_iam_role_authorizations) | **GET** /namespaceIamRoleAuthorizations | getNamespaceIamRoleAuthorizations
*NamespaceIAMRoleAuthorizationApi* | [**namespace_iam_role_authorization_get_namespace_iam_role_authorizations_by_iam_role_name**](docs/NamespaceIAMRoleAuthorizationApi.md#namespace_iam_role_authorization_get_namespace_iam_role_authorizations_by_iam_role_name) | **GET** /namespaceIamRoleAuthorizations/iamRoleNames/{iamRoleName} | getNamespaceIamRoleAuthorizationsByIamRoleName
*NamespaceIAMRoleAuthorizationApi* | [**namespace_iam_role_authorization_get_namespace_iam_role_authorizations_by_namespace**](docs/NamespaceIAMRoleAuthorizationApi.md#namespace_iam_role_authorization_get_namespace_iam_role_authorizations_by_namespace) | **GET** /namespaceIamRoleAuthorizations/namespaces/{namespace} | getNamespaceIamRoleAuthorizationsByNamespace
*NamespaceIAMRoleAuthorizationApi* | [**namespace_iam_role_authorization_update_namespace_iam_role_authorization**](docs/NamespaceIAMRoleAuthorizationApi.md#namespace_iam_role_authorization_update_namespace_iam_role_authorization) | **PUT** /namespaceIamRoleAuthorizations/namespaces/{namespace}/iamRoleNames/{iamRoleName} | updateNamespaceIamRoleAuthorization
*NotificationRegistrationStatusApi* | [**notification_registration_status_update_notification_registration_status**](docs/NotificationRegistrationStatusApi.md#notification_registration_status_update_notification_registration_status) | **PUT** /notificationRegistrationStatus/namespaces/{namespace}/notificationNames/{notificationName} | updateNotificationRegistrationStatus
*PartitionKeyGroupApi* | [**partition_key_group_create_partition_key_group**](docs/PartitionKeyGroupApi.md#partition_key_group_create_partition_key_group) | **POST** /partitionKeyGroups | createPartitionKeyGroup
*PartitionKeyGroupApi* | [**partition_key_group_delete_partition_key_group**](docs/PartitionKeyGroupApi.md#partition_key_group_delete_partition_key_group) | **DELETE** /partitionKeyGroups/{partitionKeyGroupName} | deletePartitionKeyGroup
*PartitionKeyGroupApi* | [**partition_key_group_get_partition_key_group**](docs/PartitionKeyGroupApi.md#partition_key_group_get_partition_key_group) | **GET** /partitionKeyGroups/{partitionKeyGroupName} | getPartitionKeyGroup
*PartitionKeyGroupApi* | [**partition_key_group_get_partition_key_groups**](docs/PartitionKeyGroupApi.md#partition_key_group_get_partition_key_groups) | **GET** /partitionKeyGroups | getPartitionKeyGroups
*RelationalTableRegistrationApi* | [**relational_table_registration_create_relational_table_registration**](docs/RelationalTableRegistrationApi.md#relational_table_registration_create_relational_table_registration) | **POST** /relationalTableRegistrations | createRelationalTableRegistration
*RelationalTableRegistrationApi* | [**relational_table_registration_delete_relational_table_registration**](docs/RelationalTableRegistrationApi.md#relational_table_registration_delete_relational_table_registration) | **DELETE** /relationalTableRegistrations/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage} | deleteRelationalTableRegistration
*SearchIndexApi* | [**search_index_create_search_index**](docs/SearchIndexApi.md#search_index_create_search_index) | **POST** /searchIndexes | createSearchIndex
*SearchIndexApi* | [**search_index_delete_search_index**](docs/SearchIndexApi.md#search_index_delete_search_index) | **DELETE** /searchIndexes/{searchIndexName} | deleteSearchIndex
*SearchIndexApi* | [**search_index_get_search_index**](docs/SearchIndexApi.md#search_index_get_search_index) | **GET** /searchIndexes/{searchIndexName} | getSearchIndex
*SearchIndexApi* | [**search_index_get_search_indexes**](docs/SearchIndexApi.md#search_index_get_search_indexes) | **GET** /searchIndexes | getSearchIndexes
*SearchIndexActivationApi* | [**search_index_activation_create_search_index_activation**](docs/SearchIndexActivationApi.md#search_index_activation_create_search_index_activation) | **POST** /searchIndexActivations | createSearchIndexActivation
*SecurityFunctionApi* | [**security_function_create_security_function**](docs/SecurityFunctionApi.md#security_function_create_security_function) | **POST** /securityFunctions | createSecurityFunction
*SecurityFunctionApi* | [**security_function_delete_security_function**](docs/SecurityFunctionApi.md#security_function_delete_security_function) | **DELETE** /securityFunctions/{securityFunctionName} | deleteSecurityFunction
*SecurityFunctionApi* | [**security_function_get_security_function**](docs/SecurityFunctionApi.md#security_function_get_security_function) | **GET** /securityFunctions/{securityFunctionName} | getSecurityFunction
*SecurityFunctionApi* | [**security_function_get_security_functions**](docs/SecurityFunctionApi.md#security_function_get_security_functions) | **GET** /securityFunctions | getSecurityFunctions
*SecurityRoleApi* | [**security_role_create_security_role**](docs/SecurityRoleApi.md#security_role_create_security_role) | **POST** /securityRoles | createSecurityRole
*SecurityRoleApi* | [**security_role_delete_security_role**](docs/SecurityRoleApi.md#security_role_delete_security_role) | **DELETE** /securityRoles/{securityRoleName} | deleteSecurityRole
*SecurityRoleApi* | [**security_role_get_security_role**](docs/SecurityRoleApi.md#security_role_get_security_role) | **GET** /securityRoles/{securityRoleName} | getSecurityRole
*SecurityRoleApi* | [**security_role_get_security_roles**](docs/SecurityRoleApi.md#security_role_get_security_roles) | **GET** /securityRoles | getSecurityRoles
*SecurityRoleApi* | [**security_role_update_security_role**](docs/SecurityRoleApi.md#security_role_update_security_role) | **PUT** /securityRoles/{securityRoleName} | updateSecurityRole
*SecurityRoleToFunctionMappingApi* | [**security_role_to_function_mapping_create_security_role_function**](docs/SecurityRoleToFunctionMappingApi.md#security_role_to_function_mapping_create_security_role_function) | **POST** /securityRoleFunctions | createSecurityRoleFunction
*SecurityRoleToFunctionMappingApi* | [**security_role_to_function_mapping_delete_security_role_function**](docs/SecurityRoleToFunctionMappingApi.md#security_role_to_function_mapping_delete_security_role_function) | **DELETE** /securityRoleFunctions/securityRoleNames/{securityRoleName}/securityFunctionNames/{securityFunctionName} | deleteSecurityRoleFunction
*SecurityRoleToFunctionMappingApi* | [**security_role_to_function_mapping_get_security_role_function**](docs/SecurityRoleToFunctionMappingApi.md#security_role_to_function_mapping_get_security_role_function) | **GET** /securityRoleFunctions/securityRoleNames/{securityRoleName}/securityFunctionNames/{securityFunctionName} | getSecurityRoleFunction
*SecurityRoleToFunctionMappingApi* | [**security_role_to_function_mapping_get_security_role_functions**](docs/SecurityRoleToFunctionMappingApi.md#security_role_to_function_mapping_get_security_role_functions) | **GET** /securityRoleFunctions | getSecurityRoleFunctions
*SecurityRoleToFunctionMappingApi* | [**security_role_to_function_mapping_get_security_role_functions_by_security_function**](docs/SecurityRoleToFunctionMappingApi.md#security_role_to_function_mapping_get_security_role_functions_by_security_function) | **GET** /securityRoleFunctions/securityFunctionNames/{securityFunctionName} | getSecurityRoleFunctionsBySecurityFunction
*SecurityRoleToFunctionMappingApi* | [**security_role_to_function_mapping_get_security_role_functions_by_security_role**](docs/SecurityRoleToFunctionMappingApi.md#security_role_to_function_mapping_get_security_role_functions_by_security_role) | **GET** /securityRoleFunctions/securityRoleNames/{securityRoleName} | getSecurityRoleFunctionsBySecurityRole
*StorageApi* | [**storage_create_storage**](docs/StorageApi.md#storage_create_storage) | **POST** /storages | createStorage
*StorageApi* | [**storage_delete_storage**](docs/StorageApi.md#storage_delete_storage) | **DELETE** /storages/{storageName} | deleteStorage
*StorageApi* | [**storage_get_storage**](docs/StorageApi.md#storage_get_storage) | **GET** /storages/{storageName} | getStorage
*StorageApi* | [**storage_get_storages**](docs/StorageApi.md#storage_get_storages) | **GET** /storages | getStorages
*StorageApi* | [**storage_update_storage**](docs/StorageApi.md#storage_update_storage) | **PUT** /storages/{storageName} | updateStorage
*StorageApi* | [**storage_update_storage_attributes**](docs/StorageApi.md#storage_update_storage_attributes) | **PUT** /storageAttributes/storages/{storageName} | updateStorageAttributes
*StoragePlatformApi* | [**storage_platform_get_storage_platform**](docs/StoragePlatformApi.md#storage_platform_get_storage_platform) | **GET** /storagePlatforms/{name} | getStoragePlatform
*StoragePlatformApi* | [**storage_platform_get_storage_platforms**](docs/StoragePlatformApi.md#storage_platform_get_storage_platforms) | **GET** /storagePlatforms | getStoragePlatforms
*StoragePolicyApi* | [**storage_policy_create_storage_policy**](docs/StoragePolicyApi.md#storage_policy_create_storage_policy) | **POST** /storagePolicies | createStoragePolicy
*StoragePolicyApi* | [**storage_policy_delete_storage_policy**](docs/StoragePolicyApi.md#storage_policy_delete_storage_policy) | **DELETE** /storagePolicies/namespaces/{namespace}/storagePolicyNames/{storagePolicyName} | deleteStoragePolicy
*StoragePolicyApi* | [**storage_policy_get_storage_policy**](docs/StoragePolicyApi.md#storage_policy_get_storage_policy) | **GET** /storagePolicies/namespaces/{namespace}/storagePolicyNames/{storagePolicyName} | getStoragePolicy
*StoragePolicyApi* | [**storage_policy_get_storage_policy_keys**](docs/StoragePolicyApi.md#storage_policy_get_storage_policy_keys) | **GET** /storagePolicies/namespaces/{namespace} | getStoragePolicyKeys
*StoragePolicyApi* | [**storage_policy_update_storage_policy**](docs/StoragePolicyApi.md#storage_policy_update_storage_policy) | **PUT** /storagePolicies/namespaces/{namespace}/storagePolicyNames/{storagePolicyName} | updateStoragePolicy
*StorageUnitApi* | [**storage_unit_get_storage_unit_download_credential**](docs/StorageUnitApi.md#storage_unit_get_storage_unit_download_credential) | **GET** /storageUnits/download/credential/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/businessObjectDataVersions/{businessObjectDataVersion}/storageNames/{storageName} | getStorageUnitDownloadCredential
*StorageUnitApi* | [**storage_unit_get_storage_unit_upload_credential**](docs/StorageUnitApi.md#storage_unit_get_storage_unit_upload_credential) | **GET** /storageUnits/upload/credential/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/businessObjectDataVersions/{businessObjectDataVersion}/storageNames/{storageName} | getStorageUnitUploadCredential
*StorageUnitNotificationRegistrationApi* | [**storage_unit_notification_registration_create_storage_unit_notification_registration**](docs/StorageUnitNotificationRegistrationApi.md#storage_unit_notification_registration_create_storage_unit_notification_registration) | **POST** /notificationRegistrations/storageUnitNotificationRegistrations | createStorageUnitNotificationRegistration
*StorageUnitNotificationRegistrationApi* | [**storage_unit_notification_registration_delete_storage_unit_notification**](docs/StorageUnitNotificationRegistrationApi.md#storage_unit_notification_registration_delete_storage_unit_notification) | **DELETE** /notificationRegistrations/storageUnitNotificationRegistrations/namespaces/{namespace}/notificationNames/{notificationName} | deleteStorageUnitNotification
*StorageUnitNotificationRegistrationApi* | [**storage_unit_notification_registration_get_storage_unit_notification_registration**](docs/StorageUnitNotificationRegistrationApi.md#storage_unit_notification_registration_get_storage_unit_notification_registration) | **GET** /notificationRegistrations/storageUnitNotificationRegistrations/namespaces/{namespace}/notificationNames/{notificationName} | getStorageUnitNotificationRegistration
*StorageUnitNotificationRegistrationApi* | [**storage_unit_notification_registration_get_storage_unit_notification_registrations_by_namespace**](docs/StorageUnitNotificationRegistrationApi.md#storage_unit_notification_registration_get_storage_unit_notification_registrations_by_namespace) | **GET** /notificationRegistrations/storageUnitNotificationRegistrations/namespaces/{namespace} | getStorageUnitNotificationRegistrationsByNamespace
*StorageUnitNotificationRegistrationApi* | [**storage_unit_notification_registration_get_storage_unit_notification_registrations_by_notification_filter**](docs/StorageUnitNotificationRegistrationApi.md#storage_unit_notification_registration_get_storage_unit_notification_registrations_by_notification_filter) | **GET** /notificationRegistrations/storageUnitNotificationRegistrations | getStorageUnitNotificationRegistrationsByNotificationFilter
*StorageUnitNotificationRegistrationApi* | [**storage_unit_notification_registration_update_storage_unit_notification_registration**](docs/StorageUnitNotificationRegistrationApi.md#storage_unit_notification_registration_update_storage_unit_notification_registration) | **PUT** /notificationRegistrations/storageUnitNotificationRegistrations/namespaces/{namespace}/notificationNames/{notificationName} | updateStorageUnitNotificationRegistration
*SubjectMatterExpertApi* | [**subject_matter_expert_get_subject_matter_expert**](docs/SubjectMatterExpertApi.md#subject_matter_expert_get_subject_matter_expert) | **GET** /subjectMatterExperts/{userId} | getSubjectMatterExpert
*SystemJobApi* | [**system_job_run_system_job**](docs/SystemJobApi.md#system_job_run_system_job) | **POST** /systemJobs | runSystemJob
*TagApi* | [**tag_create_tag**](docs/TagApi.md#tag_create_tag) | **POST** /tags | createTag
*TagApi* | [**tag_delete_tag**](docs/TagApi.md#tag_delete_tag) | **DELETE** /tags/tagTypes/{tagTypeCode}/tagCodes/{tagCode} | deleteTag
*TagApi* | [**tag_get_tag**](docs/TagApi.md#tag_get_tag) | **GET** /tags/tagTypes/{tagTypeCode}/tagCodes/{tagCode} | getTag
*TagApi* | [**tag_get_tags**](docs/TagApi.md#tag_get_tags) | **GET** /tags/tagTypes/{tagTypeCode} | getTags
*TagApi* | [**tag_search_tags**](docs/TagApi.md#tag_search_tags) | **POST** /tags/search | searchTags
*TagApi* | [**tag_update_tag**](docs/TagApi.md#tag_update_tag) | **PUT** /tags/tagTypes/{tagTypeCode}/tagCodes/{tagCode} | updateTag
*TagTypeApi* | [**tag_type_create_tag_type**](docs/TagTypeApi.md#tag_type_create_tag_type) | **POST** /tagTypes | createTagType
*TagTypeApi* | [**tag_type_delete_tag_type**](docs/TagTypeApi.md#tag_type_delete_tag_type) | **DELETE** /tagTypes/{tagTypeCode} | deleteTagType
*TagTypeApi* | [**tag_type_get_tag_type**](docs/TagTypeApi.md#tag_type_get_tag_type) | **GET** /tagTypes/{tagTypeCode} | getTagType
*TagTypeApi* | [**tag_type_get_tag_types**](docs/TagTypeApi.md#tag_type_get_tag_types) | **GET** /tagTypes | getTagTypes
*TagTypeApi* | [**tag_type_search_tag_types**](docs/TagTypeApi.md#tag_type_search_tag_types) | **POST** /tagTypes/search | searchTagTypes
*TagTypeApi* | [**tag_type_update_tag_type**](docs/TagTypeApi.md#tag_type_update_tag_type) | **PUT** /tagTypes/{tagTypeCode} | updateTagType
*UploadAndDownloadApi* | [**uploadand_download_extend_upload_single_credentials**](docs/UploadAndDownloadApi.md#uploadand_download_extend_upload_single_credentials) | **GET** /upload/single/credential/extension/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/businessObjectDataVersions/{businessObjectDataVersion} | extendUploadSingleCredentials
*UploadAndDownloadApi* | [**uploadand_download_initiate_download_single**](docs/UploadAndDownloadApi.md#uploadand_download_initiate_download_single) | **GET** /download/single/initiation/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/businessObjectFormatUsages/{businessObjectFormatUsage}/businessObjectFormatFileTypes/{businessObjectFormatFileType}/businessObjectFormatVersions/{businessObjectFormatVersion}/partitionValues/{partitionValue}/businessObjectDataVersions/{businessObjectDataVersion} | initiateDownloadSingle
*UploadAndDownloadApi* | [**uploadand_download_initiate_download_single_business_object_data_storage_file**](docs/UploadAndDownloadApi.md#uploadand_download_initiate_download_single_business_object_data_storage_file) | **POST** /download/businessObjectDataStorageFile/single/initiation | initiateDownloadSingleBusinessObjectDataStorageFile
*UploadAndDownloadApi* | [**uploadand_download_initiate_download_single_sample_file**](docs/UploadAndDownloadApi.md#uploadand_download_initiate_download_single_sample_file) | **POST** /download/businessObjectDefinitionSampleDataFile/single/initiation | initiateDownloadSingleSampleFile
*UploadAndDownloadApi* | [**uploadand_download_initiate_upload_sample_file**](docs/UploadAndDownloadApi.md#uploadand_download_initiate_upload_sample_file) | **POST** /upload/businessObjectDefinitionSampleDataFile/initiation | initiateUploadSampleFile
*UploadAndDownloadApi* | [**uploadand_download_initiate_upload_single**](docs/UploadAndDownloadApi.md#uploadand_download_initiate_upload_single) | **POST** /upload/single/initiation | initiateUploadSingle
*UserNamespaceAuthorizationApi* | [**user_namespace_authorization_create_user_namespace_authorization**](docs/UserNamespaceAuthorizationApi.md#user_namespace_authorization_create_user_namespace_authorization) | **POST** /userNamespaceAuthorizations | createUserNamespaceAuthorization
*UserNamespaceAuthorizationApi* | [**user_namespace_authorization_delete_user_namespace_authorization**](docs/UserNamespaceAuthorizationApi.md#user_namespace_authorization_delete_user_namespace_authorization) | **DELETE** /userNamespaceAuthorizations/userIds/{userId}/namespaces/{namespace} | deleteUserNamespaceAuthorization
*UserNamespaceAuthorizationApi* | [**user_namespace_authorization_delete_user_namespace_authorizations_by_user_id**](docs/UserNamespaceAuthorizationApi.md#user_namespace_authorization_delete_user_namespace_authorizations_by_user_id) | **DELETE** /userNamespaceAuthorizations/userIds/{userId} | deleteUserNamespaceAuthorizationsByUserId
*UserNamespaceAuthorizationApi* | [**user_namespace_authorization_get_user_namespace_authorization**](docs/UserNamespaceAuthorizationApi.md#user_namespace_authorization_get_user_namespace_authorization) | **GET** /userNamespaceAuthorizations/userIds/{userId}/namespaces/{namespace} | getUserNamespaceAuthorization
*UserNamespaceAuthorizationApi* | [**user_namespace_authorization_get_user_namespace_authorizations_by_namespace**](docs/UserNamespaceAuthorizationApi.md#user_namespace_authorization_get_user_namespace_authorizations_by_namespace) | **GET** /userNamespaceAuthorizations/namespaces/{namespace} | getUserNamespaceAuthorizationsByNamespace
*UserNamespaceAuthorizationApi* | [**user_namespace_authorization_get_user_namespace_authorizations_by_user_id**](docs/UserNamespaceAuthorizationApi.md#user_namespace_authorization_get_user_namespace_authorizations_by_user_id) | **GET** /userNamespaceAuthorizations/userIds/{userId} | getUserNamespaceAuthorizationsByUserId
*UserNamespaceAuthorizationApi* | [**user_namespace_authorization_update_user_namespace_authorization**](docs/UserNamespaceAuthorizationApi.md#user_namespace_authorization_update_user_namespace_authorization) | **PUT** /userNamespaceAuthorizations/userIds/{userId}/namespaces/{namespace} | updateUserNamespaceAuthorization


## Documentation For Models

 - [AllowedAttributeValuesCreateRequest](docs/AllowedAttributeValuesCreateRequest.md)
 - [AllowedAttributeValuesDeleteRequest](docs/AllowedAttributeValuesDeleteRequest.md)
 - [AllowedAttributeValuesInformation](docs/AllowedAttributeValuesInformation.md)
 - [Attribute](docs/Attribute.md)
 - [AttributeDefinition](docs/AttributeDefinition.md)
 - [AttributeValueFilter](docs/AttributeValueFilter.md)
 - [AttributeValueList](docs/AttributeValueList.md)
 - [AttributeValueListCreateRequest](docs/AttributeValueListCreateRequest.md)
 - [AttributeValueListKey](docs/AttributeValueListKey.md)
 - [AttributeValueListKeys](docs/AttributeValueListKeys.md)
 - [AwsCredential](docs/AwsCredential.md)
 - [BuildInformation](docs/BuildInformation.md)
 - [BusinessObjectData](docs/BusinessObjectData.md)
 - [BusinessObjectDataAttribute](docs/BusinessObjectDataAttribute.md)
 - [BusinessObjectDataAttributeCreateRequest](docs/BusinessObjectDataAttributeCreateRequest.md)
 - [BusinessObjectDataAttributeKey](docs/BusinessObjectDataAttributeKey.md)
 - [BusinessObjectDataAttributeKeys](docs/BusinessObjectDataAttributeKeys.md)
 - [BusinessObjectDataAttributeUpdateRequest](docs/BusinessObjectDataAttributeUpdateRequest.md)
 - [BusinessObjectDataAttributesUpdateRequest](docs/BusinessObjectDataAttributesUpdateRequest.md)
 - [BusinessObjectDataAvailability](docs/BusinessObjectDataAvailability.md)
 - [BusinessObjectDataAvailabilityCollectionRequest](docs/BusinessObjectDataAvailabilityCollectionRequest.md)
 - [BusinessObjectDataAvailabilityCollectionResponse](docs/BusinessObjectDataAvailabilityCollectionResponse.md)
 - [BusinessObjectDataAvailabilityRequest](docs/BusinessObjectDataAvailabilityRequest.md)
 - [BusinessObjectDataCreateRequest](docs/BusinessObjectDataCreateRequest.md)
 - [BusinessObjectDataDdl](docs/BusinessObjectDataDdl.md)
 - [BusinessObjectDataDdlCollectionRequest](docs/BusinessObjectDataDdlCollectionRequest.md)
 - [BusinessObjectDataDdlCollectionResponse](docs/BusinessObjectDataDdlCollectionResponse.md)
 - [BusinessObjectDataDdlOutputFormatEnum](docs/BusinessObjectDataDdlOutputFormatEnum.md)
 - [BusinessObjectDataDdlRequest](docs/BusinessObjectDataDdlRequest.md)
 - [BusinessObjectDataDownloadCredential](docs/BusinessObjectDataDownloadCredential.md)
 - [BusinessObjectDataInvalidateUnregisteredRequest](docs/BusinessObjectDataInvalidateUnregisteredRequest.md)
 - [BusinessObjectDataInvalidateUnregisteredResponse](docs/BusinessObjectDataInvalidateUnregisteredResponse.md)
 - [BusinessObjectDataKey](docs/BusinessObjectDataKey.md)
 - [BusinessObjectDataKeys](docs/BusinessObjectDataKeys.md)
 - [BusinessObjectDataLegalHoldUpdateRequest](docs/BusinessObjectDataLegalHoldUpdateRequest.md)
 - [BusinessObjectDataNotificationFilter](docs/BusinessObjectDataNotificationFilter.md)
 - [BusinessObjectDataNotificationRegistration](docs/BusinessObjectDataNotificationRegistration.md)
 - [BusinessObjectDataNotificationRegistrationCreateRequest](docs/BusinessObjectDataNotificationRegistrationCreateRequest.md)
 - [BusinessObjectDataNotificationRegistrationKeys](docs/BusinessObjectDataNotificationRegistrationKeys.md)
 - [BusinessObjectDataNotificationRegistrationUpdateRequest](docs/BusinessObjectDataNotificationRegistrationUpdateRequest.md)
 - [BusinessObjectDataParentsUpdateRequest](docs/BusinessObjectDataParentsUpdateRequest.md)
 - [BusinessObjectDataPartitions](docs/BusinessObjectDataPartitions.md)
 - [BusinessObjectDataPartitionsRequest](docs/BusinessObjectDataPartitionsRequest.md)
 - [BusinessObjectDataRetentionInformationUpdateRequest](docs/BusinessObjectDataRetentionInformationUpdateRequest.md)
 - [BusinessObjectDataRetryStoragePolicyTransitionRequest](docs/BusinessObjectDataRetryStoragePolicyTransitionRequest.md)
 - [BusinessObjectDataSearchFilter](docs/BusinessObjectDataSearchFilter.md)
 - [BusinessObjectDataSearchKey](docs/BusinessObjectDataSearchKey.md)
 - [BusinessObjectDataSearchRequest](docs/BusinessObjectDataSearchRequest.md)
 - [BusinessObjectDataSearchResult](docs/BusinessObjectDataSearchResult.md)
 - [BusinessObjectDataStatus](docs/BusinessObjectDataStatus.md)
 - [BusinessObjectDataStatusChangeEvent](docs/BusinessObjectDataStatusChangeEvent.md)
 - [BusinessObjectDataStatusInformation](docs/BusinessObjectDataStatusInformation.md)
 - [BusinessObjectDataStatusUpdateRequest](docs/BusinessObjectDataStatusUpdateRequest.md)
 - [BusinessObjectDataStatusUpdateResponse](docs/BusinessObjectDataStatusUpdateResponse.md)
 - [BusinessObjectDataStorageFileKey](docs/BusinessObjectDataStorageFileKey.md)
 - [BusinessObjectDataStorageFilesCreateRequest](docs/BusinessObjectDataStorageFilesCreateRequest.md)
 - [BusinessObjectDataStorageFilesCreateResponse](docs/BusinessObjectDataStorageFilesCreateResponse.md)
 - [BusinessObjectDataStorageUnitCreateRequest](docs/BusinessObjectDataStorageUnitCreateRequest.md)
 - [BusinessObjectDataStorageUnitCreateResponse](docs/BusinessObjectDataStorageUnitCreateResponse.md)
 - [BusinessObjectDataStorageUnitKey](docs/BusinessObjectDataStorageUnitKey.md)
 - [BusinessObjectDataStorageUnitStatusUpdateRequest](docs/BusinessObjectDataStorageUnitStatusUpdateRequest.md)
 - [BusinessObjectDataStorageUnitStatusUpdateResponse](docs/BusinessObjectDataStorageUnitStatusUpdateResponse.md)
 - [BusinessObjectDataUploadCredential](docs/BusinessObjectDataUploadCredential.md)
 - [BusinessObjectDataVersion](docs/BusinessObjectDataVersion.md)
 - [BusinessObjectDataVersions](docs/BusinessObjectDataVersions.md)
 - [BusinessObjectDefinition](docs/BusinessObjectDefinition.md)
 - [BusinessObjectDefinitionChangeEvent](docs/BusinessObjectDefinitionChangeEvent.md)
 - [BusinessObjectDefinitionColumn](docs/BusinessObjectDefinitionColumn.md)
 - [BusinessObjectDefinitionColumnChangeEvent](docs/BusinessObjectDefinitionColumnChangeEvent.md)
 - [BusinessObjectDefinitionColumnCreateRequest](docs/BusinessObjectDefinitionColumnCreateRequest.md)
 - [BusinessObjectDefinitionColumnKey](docs/BusinessObjectDefinitionColumnKey.md)
 - [BusinessObjectDefinitionColumnKeys](docs/BusinessObjectDefinitionColumnKeys.md)
 - [BusinessObjectDefinitionColumnSearchFilter](docs/BusinessObjectDefinitionColumnSearchFilter.md)
 - [BusinessObjectDefinitionColumnSearchKey](docs/BusinessObjectDefinitionColumnSearchKey.md)
 - [BusinessObjectDefinitionColumnSearchRequest](docs/BusinessObjectDefinitionColumnSearchRequest.md)
 - [BusinessObjectDefinitionColumnSearchResponse](docs/BusinessObjectDefinitionColumnSearchResponse.md)
 - [BusinessObjectDefinitionColumnUpdateRequest](docs/BusinessObjectDefinitionColumnUpdateRequest.md)
 - [BusinessObjectDefinitionCreateRequest](docs/BusinessObjectDefinitionCreateRequest.md)
 - [BusinessObjectDefinitionDescriptionSuggestion](docs/BusinessObjectDefinitionDescriptionSuggestion.md)
 - [BusinessObjectDefinitionDescriptionSuggestionAcceptanceRequest](docs/BusinessObjectDefinitionDescriptionSuggestionAcceptanceRequest.md)
 - [BusinessObjectDefinitionDescriptionSuggestionCreateRequest](docs/BusinessObjectDefinitionDescriptionSuggestionCreateRequest.md)
 - [BusinessObjectDefinitionDescriptionSuggestionKey](docs/BusinessObjectDefinitionDescriptionSuggestionKey.md)
 - [BusinessObjectDefinitionDescriptionSuggestionKeys](docs/BusinessObjectDefinitionDescriptionSuggestionKeys.md)
 - [BusinessObjectDefinitionDescriptionSuggestionSearchFilter](docs/BusinessObjectDefinitionDescriptionSuggestionSearchFilter.md)
 - [BusinessObjectDefinitionDescriptionSuggestionSearchKey](docs/BusinessObjectDefinitionDescriptionSuggestionSearchKey.md)
 - [BusinessObjectDefinitionDescriptionSuggestionSearchRequest](docs/BusinessObjectDefinitionDescriptionSuggestionSearchRequest.md)
 - [BusinessObjectDefinitionDescriptionSuggestionSearchResponse](docs/BusinessObjectDefinitionDescriptionSuggestionSearchResponse.md)
 - [BusinessObjectDefinitionDescriptionSuggestionUpdateRequest](docs/BusinessObjectDefinitionDescriptionSuggestionUpdateRequest.md)
 - [BusinessObjectDefinitionDescriptiveInformationUpdateRequest](docs/BusinessObjectDefinitionDescriptiveInformationUpdateRequest.md)
 - [BusinessObjectDefinitionIndexResponse](docs/BusinessObjectDefinitionIndexResponse.md)
 - [BusinessObjectDefinitionKey](docs/BusinessObjectDefinitionKey.md)
 - [BusinessObjectDefinitionKeys](docs/BusinessObjectDefinitionKeys.md)
 - [BusinessObjectDefinitionSampleDataFileKey](docs/BusinessObjectDefinitionSampleDataFileKey.md)
 - [BusinessObjectDefinitionSearchFilter](docs/BusinessObjectDefinitionSearchFilter.md)
 - [BusinessObjectDefinitionSearchKey](docs/BusinessObjectDefinitionSearchKey.md)
 - [BusinessObjectDefinitionSearchRequest](docs/BusinessObjectDefinitionSearchRequest.md)
 - [BusinessObjectDefinitionSearchResponse](docs/BusinessObjectDefinitionSearchResponse.md)
 - [BusinessObjectDefinitionSubjectMatterExpert](docs/BusinessObjectDefinitionSubjectMatterExpert.md)
 - [BusinessObjectDefinitionSubjectMatterExpertCreateRequest](docs/BusinessObjectDefinitionSubjectMatterExpertCreateRequest.md)
 - [BusinessObjectDefinitionSubjectMatterExpertKey](docs/BusinessObjectDefinitionSubjectMatterExpertKey.md)
 - [BusinessObjectDefinitionSubjectMatterExpertKeys](docs/BusinessObjectDefinitionSubjectMatterExpertKeys.md)
 - [BusinessObjectDefinitionTag](docs/BusinessObjectDefinitionTag.md)
 - [BusinessObjectDefinitionTagCreateRequest](docs/BusinessObjectDefinitionTagCreateRequest.md)
 - [BusinessObjectDefinitionTagKey](docs/BusinessObjectDefinitionTagKey.md)
 - [BusinessObjectDefinitionTagKeys](docs/BusinessObjectDefinitionTagKeys.md)
 - [BusinessObjectDefinitionUpdateRequest](docs/BusinessObjectDefinitionUpdateRequest.md)
 - [BusinessObjectFormat](docs/BusinessObjectFormat.md)
 - [BusinessObjectFormatAttributeDefinitionsUpdateRequest](docs/BusinessObjectFormatAttributeDefinitionsUpdateRequest.md)
 - [BusinessObjectFormatAttributesUpdateRequest](docs/BusinessObjectFormatAttributesUpdateRequest.md)
 - [BusinessObjectFormatCreateRequest](docs/BusinessObjectFormatCreateRequest.md)
 - [BusinessObjectFormatDdl](docs/BusinessObjectFormatDdl.md)
 - [BusinessObjectFormatDdlCollectionRequest](docs/BusinessObjectFormatDdlCollectionRequest.md)
 - [BusinessObjectFormatDdlCollectionResponse](docs/BusinessObjectFormatDdlCollectionResponse.md)
 - [BusinessObjectFormatDdlRequest](docs/BusinessObjectFormatDdlRequest.md)
 - [BusinessObjectFormatExternalInterface](docs/BusinessObjectFormatExternalInterface.md)
 - [BusinessObjectFormatExternalInterfaceCreateRequest](docs/BusinessObjectFormatExternalInterfaceCreateRequest.md)
 - [BusinessObjectFormatExternalInterfaceDescriptiveInformation](docs/BusinessObjectFormatExternalInterfaceDescriptiveInformation.md)
 - [BusinessObjectFormatExternalInterfaceKey](docs/BusinessObjectFormatExternalInterfaceKey.md)
 - [BusinessObjectFormatKey](docs/BusinessObjectFormatKey.md)
 - [BusinessObjectFormatKeys](docs/BusinessObjectFormatKeys.md)
 - [BusinessObjectFormatLegalHoldUpdateRequest](docs/BusinessObjectFormatLegalHoldUpdateRequest.md)
 - [BusinessObjectFormatParentsUpdateRequest](docs/BusinessObjectFormatParentsUpdateRequest.md)
 - [BusinessObjectFormatRecordFlagUpdateRequest](docs/BusinessObjectFormatRecordFlagUpdateRequest.md)
 - [BusinessObjectFormatRetentionInformationUpdateRequest](docs/BusinessObjectFormatRetentionInformationUpdateRequest.md)
 - [BusinessObjectFormatSchemaBackwardsCompatibilityUpdateRequest](docs/BusinessObjectFormatSchemaBackwardsCompatibilityUpdateRequest.md)
 - [BusinessObjectFormatUpdateRequest](docs/BusinessObjectFormatUpdateRequest.md)
 - [ConfigurationEntry](docs/ConfigurationEntry.md)
 - [ConfigurationEntryKeys](docs/ConfigurationEntryKeys.md)
 - [ConfigurationFile](docs/ConfigurationFile.md)
 - [ConfigurationFiles](docs/ConfigurationFiles.md)
 - [CustomDdl](docs/CustomDdl.md)
 - [CustomDdlCreateRequest](docs/CustomDdlCreateRequest.md)
 - [CustomDdlKey](docs/CustomDdlKey.md)
 - [CustomDdlKeys](docs/CustomDdlKeys.md)
 - [CustomDdlUpdateRequest](docs/CustomDdlUpdateRequest.md)
 - [DataProvider](docs/DataProvider.md)
 - [DataProviderCreateRequest](docs/DataProviderCreateRequest.md)
 - [DataProviderKey](docs/DataProviderKey.md)
 - [DataProviderKeys](docs/DataProviderKeys.md)
 - [DescriptiveBusinessObjectFormat](docs/DescriptiveBusinessObjectFormat.md)
 - [DescriptiveBusinessObjectFormatUpdateRequest](docs/DescriptiveBusinessObjectFormatUpdateRequest.md)
 - [DownloadBusinessObjectDataStorageFileSingleInitiationRequest](docs/DownloadBusinessObjectDataStorageFileSingleInitiationRequest.md)
 - [DownloadBusinessObjectDataStorageFileSingleInitiationResponse](docs/DownloadBusinessObjectDataStorageFileSingleInitiationResponse.md)
 - [DownloadBusinessObjectDefinitionSampleDataFileSingleInitiationRequest](docs/DownloadBusinessObjectDefinitionSampleDataFileSingleInitiationRequest.md)
 - [DownloadBusinessObjectDefinitionSampleDataFileSingleInitiationResponse](docs/DownloadBusinessObjectDefinitionSampleDataFileSingleInitiationResponse.md)
 - [DownloadSingleInitiationResponse](docs/DownloadSingleInitiationResponse.md)
 - [EmailSendRequest](docs/EmailSendRequest.md)
 - [EmrCluster](docs/EmrCluster.md)
 - [EmrClusterCreateRequest](docs/EmrClusterCreateRequest.md)
 - [EmrClusterDefinition](docs/EmrClusterDefinition.md)
 - [EmrClusterDefinitionApplication](docs/EmrClusterDefinitionApplication.md)
 - [EmrClusterDefinitionAutoTerminationPolicy](docs/EmrClusterDefinitionAutoTerminationPolicy.md)
 - [EmrClusterDefinitionCapacityReservationOptions](docs/EmrClusterDefinitionCapacityReservationOptions.md)
 - [EmrClusterDefinitionConfiguration](docs/EmrClusterDefinitionConfiguration.md)
 - [EmrClusterDefinitionCreateRequest](docs/EmrClusterDefinitionCreateRequest.md)
 - [EmrClusterDefinitionEbsBlockDeviceConfig](docs/EmrClusterDefinitionEbsBlockDeviceConfig.md)
 - [EmrClusterDefinitionEbsConfiguration](docs/EmrClusterDefinitionEbsConfiguration.md)
 - [EmrClusterDefinitionInformation](docs/EmrClusterDefinitionInformation.md)
 - [EmrClusterDefinitionInstanceFleet](docs/EmrClusterDefinitionInstanceFleet.md)
 - [EmrClusterDefinitionInstanceTypeConfig](docs/EmrClusterDefinitionInstanceTypeConfig.md)
 - [EmrClusterDefinitionKerberosAttributes](docs/EmrClusterDefinitionKerberosAttributes.md)
 - [EmrClusterDefinitionKey](docs/EmrClusterDefinitionKey.md)
 - [EmrClusterDefinitionKeys](docs/EmrClusterDefinitionKeys.md)
 - [EmrClusterDefinitionLaunchSpecifications](docs/EmrClusterDefinitionLaunchSpecifications.md)
 - [EmrClusterDefinitionOnDemandSpecification](docs/EmrClusterDefinitionOnDemandSpecification.md)
 - [EmrClusterDefinitionSpotSpecification](docs/EmrClusterDefinitionSpotSpecification.md)
 - [EmrClusterDefinitionUpdateRequest](docs/EmrClusterDefinitionUpdateRequest.md)
 - [EmrClusterDefinitionVolumeSpecification](docs/EmrClusterDefinitionVolumeSpecification.md)
 - [EmrClusterEbsBlockDevice](docs/EmrClusterEbsBlockDevice.md)
 - [EmrClusterInstanceFleet](docs/EmrClusterInstanceFleet.md)
 - [EmrClusterInstanceFleetProvisioningSpecifications](docs/EmrClusterInstanceFleetProvisioningSpecifications.md)
 - [EmrClusterInstanceFleetStateChangeReason](docs/EmrClusterInstanceFleetStateChangeReason.md)
 - [EmrClusterInstanceFleetStatus](docs/EmrClusterInstanceFleetStatus.md)
 - [EmrClusterInstanceFleetTimeline](docs/EmrClusterInstanceFleetTimeline.md)
 - [EmrClusterInstanceTypeConfiguration](docs/EmrClusterInstanceTypeConfiguration.md)
 - [EmrClusterInstanceTypeSpecification](docs/EmrClusterInstanceTypeSpecification.md)
 - [EmrClusterSpotProvisioningSpecification](docs/EmrClusterSpotProvisioningSpecification.md)
 - [EmrClusterVolumeSpecification](docs/EmrClusterVolumeSpecification.md)
 - [EmrHadoopJarStep](docs/EmrHadoopJarStep.md)
 - [EmrHadoopJarStepAddRequest](docs/EmrHadoopJarStepAddRequest.md)
 - [EmrHiveStep](docs/EmrHiveStep.md)
 - [EmrHiveStepAddRequest](docs/EmrHiveStepAddRequest.md)
 - [EmrMasterSecurityGroup](docs/EmrMasterSecurityGroup.md)
 - [EmrMasterSecurityGroupAddRequest](docs/EmrMasterSecurityGroupAddRequest.md)
 - [EmrPigStep](docs/EmrPigStep.md)
 - [EmrPigStepAddRequest](docs/EmrPigStepAddRequest.md)
 - [EmrShellStep](docs/EmrShellStep.md)
 - [EmrShellStepAddRequest](docs/EmrShellStepAddRequest.md)
 - [EmrStep](docs/EmrStep.md)
 - [ErrorInformation](docs/ErrorInformation.md)
 - [ExpectedPartitionValueInformation](docs/ExpectedPartitionValueInformation.md)
 - [ExpectedPartitionValueKey](docs/ExpectedPartitionValueKey.md)
 - [ExpectedPartitionValuesCreateRequest](docs/ExpectedPartitionValuesCreateRequest.md)
 - [ExpectedPartitionValuesDeleteRequest](docs/ExpectedPartitionValuesDeleteRequest.md)
 - [ExpectedPartitionValuesInformation](docs/ExpectedPartitionValuesInformation.md)
 - [ExternalInterface](docs/ExternalInterface.md)
 - [ExternalInterfaceCreateRequest](docs/ExternalInterfaceCreateRequest.md)
 - [ExternalInterfaceKey](docs/ExternalInterfaceKey.md)
 - [ExternalInterfaceKeys](docs/ExternalInterfaceKeys.md)
 - [ExternalInterfaceUpdateRequest](docs/ExternalInterfaceUpdateRequest.md)
 - [Facet](docs/Facet.md)
 - [Field](docs/Field.md)
 - [File](docs/File.md)
 - [FileType](docs/FileType.md)
 - [FileTypeCreateRequest](docs/FileTypeCreateRequest.md)
 - [FileTypeKey](docs/FileTypeKey.md)
 - [FileTypeKeys](docs/FileTypeKeys.md)
 - [GlobalAttributeDefinition](docs/GlobalAttributeDefinition.md)
 - [GlobalAttributeDefinitionCreateRequest](docs/GlobalAttributeDefinitionCreateRequest.md)
 - [GlobalAttributeDefinitionKey](docs/GlobalAttributeDefinitionKey.md)
 - [GlobalAttributeDefinitionKeys](docs/GlobalAttributeDefinitionKeys.md)
 - [HadoopJarStep](docs/HadoopJarStep.md)
 - [Highlight](docs/Highlight.md)
 - [IndexSearchFilter](docs/IndexSearchFilter.md)
 - [IndexSearchKey](docs/IndexSearchKey.md)
 - [IndexSearchRequest](docs/IndexSearchRequest.md)
 - [IndexSearchResponse](docs/IndexSearchResponse.md)
 - [IndexSearchResult](docs/IndexSearchResult.md)
 - [IndexSearchResultKey](docs/IndexSearchResultKey.md)
 - [IndexSearchResultTypeKey](docs/IndexSearchResultTypeKey.md)
 - [InstanceDefinition](docs/InstanceDefinition.md)
 - [InstanceDefinitions](docs/InstanceDefinitions.md)
 - [JdbcConnection](docs/JdbcConnection.md)
 - [JdbcDatabaseType](docs/JdbcDatabaseType.md)
 - [JdbcExecutionRequest](docs/JdbcExecutionRequest.md)
 - [JdbcExecutionResponse](docs/JdbcExecutionResponse.md)
 - [JdbcStatement](docs/JdbcStatement.md)
 - [JdbcStatementResultSet](docs/JdbcStatementResultSet.md)
 - [JdbcStatementResultSetRow](docs/JdbcStatementResultSetRow.md)
 - [JdbcStatementStatus](docs/JdbcStatementStatus.md)
 - [JdbcStatementType](docs/JdbcStatementType.md)
 - [Job](docs/Job.md)
 - [JobAction](docs/JobAction.md)
 - [JobActionEnum](docs/JobActionEnum.md)
 - [JobCreateRequest](docs/JobCreateRequest.md)
 - [JobDefinition](docs/JobDefinition.md)
 - [JobDefinitionCreateRequest](docs/JobDefinitionCreateRequest.md)
 - [JobDefinitionKey](docs/JobDefinitionKey.md)
 - [JobDefinitionKeys](docs/JobDefinitionKeys.md)
 - [JobDefinitionUpdateRequest](docs/JobDefinitionUpdateRequest.md)
 - [JobDeleteRequest](docs/JobDeleteRequest.md)
 - [JobSignalRequest](docs/JobSignalRequest.md)
 - [JobStatusEnum](docs/JobStatusEnum.md)
 - [JobSummaries](docs/JobSummaries.md)
 - [JobSummary](docs/JobSummary.md)
 - [JobUpdateRequest](docs/JobUpdateRequest.md)
 - [KeyValuePairConfiguration](docs/KeyValuePairConfiguration.md)
 - [KeyValuePairConfigurations](docs/KeyValuePairConfigurations.md)
 - [LatestAfterPartitionValue](docs/LatestAfterPartitionValue.md)
 - [LatestBeforePartitionValue](docs/LatestBeforePartitionValue.md)
 - [MasterInstanceDefinition](docs/MasterInstanceDefinition.md)
 - [MessageHeaderDefinition](docs/MessageHeaderDefinition.md)
 - [Namespace](docs/Namespace.md)
 - [NamespaceAuthorization](docs/NamespaceAuthorization.md)
 - [NamespaceCreateRequest](docs/NamespaceCreateRequest.md)
 - [NamespaceIamRoleAuthorization](docs/NamespaceIamRoleAuthorization.md)
 - [NamespaceIamRoleAuthorizationCreateRequest](docs/NamespaceIamRoleAuthorizationCreateRequest.md)
 - [NamespaceIamRoleAuthorizationKey](docs/NamespaceIamRoleAuthorizationKey.md)
 - [NamespaceIamRoleAuthorizationKeys](docs/NamespaceIamRoleAuthorizationKeys.md)
 - [NamespaceIamRoleAuthorizationUpdateRequest](docs/NamespaceIamRoleAuthorizationUpdateRequest.md)
 - [NamespaceKey](docs/NamespaceKey.md)
 - [NamespaceKeys](docs/NamespaceKeys.md)
 - [NamespacePermissionEnum](docs/NamespacePermissionEnum.md)
 - [NamespaceSearchFilter](docs/NamespaceSearchFilter.md)
 - [NamespaceSearchKey](docs/NamespaceSearchKey.md)
 - [NamespaceSearchRequest](docs/NamespaceSearchRequest.md)
 - [NamespaceSearchResponse](docs/NamespaceSearchResponse.md)
 - [NamespaceUpdateRequest](docs/NamespaceUpdateRequest.md)
 - [NodeTag](docs/NodeTag.md)
 - [NotificationMessageDefinition](docs/NotificationMessageDefinition.md)
 - [NotificationMessageDefinitions](docs/NotificationMessageDefinitions.md)
 - [NotificationRegistrationKey](docs/NotificationRegistrationKey.md)
 - [NotificationRegistrationStatusUpdateRequest](docs/NotificationRegistrationStatusUpdateRequest.md)
 - [NotificationRegistrationStatusUpdateResponse](docs/NotificationRegistrationStatusUpdateResponse.md)
 - [Parameter](docs/Parameter.md)
 - [Partition](docs/Partition.md)
 - [PartitionColumn](docs/PartitionColumn.md)
 - [PartitionKeyGroup](docs/PartitionKeyGroup.md)
 - [PartitionKeyGroupCreateRequest](docs/PartitionKeyGroupCreateRequest.md)
 - [PartitionKeyGroupKey](docs/PartitionKeyGroupKey.md)
 - [PartitionKeyGroupKeys](docs/PartitionKeyGroupKeys.md)
 - [PartitionValueFilter](docs/PartitionValueFilter.md)
 - [PartitionValueRange](docs/PartitionValueRange.md)
 - [RegistrationDateRangeFilter](docs/RegistrationDateRangeFilter.md)
 - [RelationalTableRegistrationCreateRequest](docs/RelationalTableRegistrationCreateRequest.md)
 - [RelationalTableRegistrationDeleteResponse](docs/RelationalTableRegistrationDeleteResponse.md)
 - [RunOozieWorkflowRequest](docs/RunOozieWorkflowRequest.md)
 - [S3KeyPrefixInformation](docs/S3KeyPrefixInformation.md)
 - [S3PropertiesLocation](docs/S3PropertiesLocation.md)
 - [SampleDataFile](docs/SampleDataFile.md)
 - [Schema](docs/Schema.md)
 - [SchemaColumn](docs/SchemaColumn.md)
 - [ScriptDefinition](docs/ScriptDefinition.md)
 - [SearchIndex](docs/SearchIndex.md)
 - [SearchIndexActivation](docs/SearchIndexActivation.md)
 - [SearchIndexActivationCreateRequest](docs/SearchIndexActivationCreateRequest.md)
 - [SearchIndexCreateRequest](docs/SearchIndexCreateRequest.md)
 - [SearchIndexKey](docs/SearchIndexKey.md)
 - [SearchIndexKeys](docs/SearchIndexKeys.md)
 - [SearchIndexStatistics](docs/SearchIndexStatistics.md)
 - [SecurityFunction](docs/SecurityFunction.md)
 - [SecurityFunctionCreateRequest](docs/SecurityFunctionCreateRequest.md)
 - [SecurityFunctionKey](docs/SecurityFunctionKey.md)
 - [SecurityFunctionKeys](docs/SecurityFunctionKeys.md)
 - [SecurityRole](docs/SecurityRole.md)
 - [SecurityRoleCreateRequest](docs/SecurityRoleCreateRequest.md)
 - [SecurityRoleFunction](docs/SecurityRoleFunction.md)
 - [SecurityRoleFunctionCreateRequest](docs/SecurityRoleFunctionCreateRequest.md)
 - [SecurityRoleFunctionKey](docs/SecurityRoleFunctionKey.md)
 - [SecurityRoleFunctionKeys](docs/SecurityRoleFunctionKeys.md)
 - [SecurityRoleKey](docs/SecurityRoleKey.md)
 - [SecurityRoleKeys](docs/SecurityRoleKeys.md)
 - [SecurityRoleUpdateRequest](docs/SecurityRoleUpdateRequest.md)
 - [StatusChangeReason](docs/StatusChangeReason.md)
 - [StatusTimeline](docs/StatusTimeline.md)
 - [Storage](docs/Storage.md)
 - [StorageAttributesUpdateRequest](docs/StorageAttributesUpdateRequest.md)
 - [StorageBusinessObjectDefinitionDailyUploadStat](docs/StorageBusinessObjectDefinitionDailyUploadStat.md)
 - [StorageBusinessObjectDefinitionDailyUploadStats](docs/StorageBusinessObjectDefinitionDailyUploadStats.md)
 - [StorageCreateRequest](docs/StorageCreateRequest.md)
 - [StorageDailyUploadStat](docs/StorageDailyUploadStat.md)
 - [StorageDailyUploadStats](docs/StorageDailyUploadStats.md)
 - [StorageDirectory](docs/StorageDirectory.md)
 - [StorageFile](docs/StorageFile.md)
 - [StorageKey](docs/StorageKey.md)
 - [StorageKeys](docs/StorageKeys.md)
 - [StoragePlatform](docs/StoragePlatform.md)
 - [StoragePlatforms](docs/StoragePlatforms.md)
 - [StoragePolicy](docs/StoragePolicy.md)
 - [StoragePolicyCreateRequest](docs/StoragePolicyCreateRequest.md)
 - [StoragePolicyFilter](docs/StoragePolicyFilter.md)
 - [StoragePolicyKey](docs/StoragePolicyKey.md)
 - [StoragePolicyKeys](docs/StoragePolicyKeys.md)
 - [StoragePolicyRule](docs/StoragePolicyRule.md)
 - [StoragePolicyTransition](docs/StoragePolicyTransition.md)
 - [StoragePolicyUpdateRequest](docs/StoragePolicyUpdateRequest.md)
 - [StorageUnit](docs/StorageUnit.md)
 - [StorageUnitCreateRequest](docs/StorageUnitCreateRequest.md)
 - [StorageUnitDownloadCredential](docs/StorageUnitDownloadCredential.md)
 - [StorageUnitNotificationFilter](docs/StorageUnitNotificationFilter.md)
 - [StorageUnitNotificationRegistration](docs/StorageUnitNotificationRegistration.md)
 - [StorageUnitNotificationRegistrationCreateRequest](docs/StorageUnitNotificationRegistrationCreateRequest.md)
 - [StorageUnitNotificationRegistrationKeys](docs/StorageUnitNotificationRegistrationKeys.md)
 - [StorageUnitNotificationRegistrationUpdateRequest](docs/StorageUnitNotificationRegistrationUpdateRequest.md)
 - [StorageUnitStatusChangeEvent](docs/StorageUnitStatusChangeEvent.md)
 - [StorageUnitUploadCredential](docs/StorageUnitUploadCredential.md)
 - [StorageUpdateRequest](docs/StorageUpdateRequest.md)
 - [SubjectMatterExpert](docs/SubjectMatterExpert.md)
 - [SubjectMatterExpertContactDetails](docs/SubjectMatterExpertContactDetails.md)
 - [SubjectMatterExpertKey](docs/SubjectMatterExpertKey.md)
 - [SystemJobRunRequest](docs/SystemJobRunRequest.md)
 - [SystemJobRunResponse](docs/SystemJobRunResponse.md)
 - [Tag](docs/Tag.md)
 - [TagChild](docs/TagChild.md)
 - [TagCreateRequest](docs/TagCreateRequest.md)
 - [TagKey](docs/TagKey.md)
 - [TagListResponse](docs/TagListResponse.md)
 - [TagSearchFilter](docs/TagSearchFilter.md)
 - [TagSearchKey](docs/TagSearchKey.md)
 - [TagSearchRequest](docs/TagSearchRequest.md)
 - [TagSearchResponse](docs/TagSearchResponse.md)
 - [TagType](docs/TagType.md)
 - [TagTypeCreateRequest](docs/TagTypeCreateRequest.md)
 - [TagTypeKey](docs/TagTypeKey.md)
 - [TagTypeKeys](docs/TagTypeKeys.md)
 - [TagTypeSearchRequest](docs/TagTypeSearchRequest.md)
 - [TagTypeSearchResponse](docs/TagTypeSearchResponse.md)
 - [TagTypeUpdateRequest](docs/TagTypeUpdateRequest.md)
 - [TagUpdateRequest](docs/TagUpdateRequest.md)
 - [TimeoutValidationResponse](docs/TimeoutValidationResponse.md)
 - [UploadBusinessObjectDefinitionSampleDataFileInitiationRequest](docs/UploadBusinessObjectDefinitionSampleDataFileInitiationRequest.md)
 - [UploadBusinessObjectDefinitionSampleDataFileInitiationResponse](docs/UploadBusinessObjectDefinitionSampleDataFileInitiationResponse.md)
 - [UploadSingleCredentialExtensionResponse](docs/UploadSingleCredentialExtensionResponse.md)
 - [UploadSingleInitiationRequest](docs/UploadSingleInitiationRequest.md)
 - [UploadSingleInitiationResponse](docs/UploadSingleInitiationResponse.md)
 - [UserAuthorizations](docs/UserAuthorizations.md)
 - [UserNamespaceAuthorization](docs/UserNamespaceAuthorization.md)
 - [UserNamespaceAuthorizationCreateRequest](docs/UserNamespaceAuthorizationCreateRequest.md)
 - [UserNamespaceAuthorizationKey](docs/UserNamespaceAuthorizationKey.md)
 - [UserNamespaceAuthorizationUpdateRequest](docs/UserNamespaceAuthorizationUpdateRequest.md)
 - [UserNamespaceAuthorizations](docs/UserNamespaceAuthorizations.md)
 - [WorkflowError](docs/WorkflowError.md)
 - [WorkflowStep](docs/WorkflowStep.md)


## Documentation For Authorization


## basicAuth

- **Type**: HTTP basic authentication

## oauthAuth

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: N/A


## Author




